@@ -30,53 +30,6 @@ static guint s_iSignals[NB_SIGNALS] = { 0 };
 static guint s_iSubSignals[NB_SIGNALS] = { 0 };
 
 
-static void g_cclosure_marshal_VOID__INT_STRING (GClosure *closure,
-	GValue *return_value,
-	guint n_param_values,
-	const GValue *param_values,
-	gpointer invocation_hint,
-	gpointer marshal_data)
-{
-	g_print ("%s ()\n", __func__);
-}
-static void g_cclosure_marshal_VOID__BOOLEAN_STRING (GClosure *closure,
-	GValue *return_value,
-	guint n_param_values,
-	const GValue *param_values,
-	gpointer invocation_hint,
-	gpointer marshal_data)
-{
-	g_print ("%s ()\n", __func__);
-}
-static void g_cclosure_marshal_VOID__STRING_STRING (GClosure *closure,
-	GValue *return_value,
-	guint n_param_values,
-	const GValue *param_values,
-	gpointer invocation_hint,
-	gpointer marshal_data)
-{
-	g_print ("%s ()\n", __func__);
-}
-
-static void g_cclosure_marshal_VOID__VALUE (GClosure *closure,
-	GValue *return_value,
-	guint n_param_values,
-	const GValue *param_values,
-	gpointer invocation_hint,
-	gpointer marshal_data)
-{
-	g_print ("%s ()\n", __func__);
-}
-static void g_cclosure_marshal_VOID__VALUE_STRING (GClosure *closure,
-	GValue *return_value,
-	guint n_param_values,
-	const GValue *param_values,
-	gpointer invocation_hint,
-	gpointer marshal_data)
-{
-	g_print ("%s ()\n", __func__);
-}
-
 void cd_dbus_applet_init_signals_once (dbusAppletClass *klass)
 {
 	static gboolean bFirst = TRUE;
@@ -85,8 +38,10 @@ void cd_dbus_applet_init_signals_once (dbusAppletClass *klass)
 	bFirst = FALSE;
 	
 	// Enregistrement des marshaller specifique aux signaux.
-	dbus_g_object_register_marshaller(g_cclosure_marshal_VOID__VALUE,
+	dbus_g_object_register_marshaller(cd_dbus_marshal_VOID__VALUE,
 		G_TYPE_NONE, G_TYPE_VALUE, G_TYPE_INVALID);  // answer
+	dbus_g_object_register_marshaller(cd_dbus_marshal_VOID__INT_VALUE,
+		G_TYPE_NONE, G_TYPE_INT, G_TYPE_VALUE, G_TYPE_INVALID);  // answer_dialog
 	
 	// on definit les signaux dont on aura besoin.
 	s_iSignals[CLIC] =
@@ -95,7 +50,7 @@ void cd_dbus_applet_init_signals_once (dbusAppletClass *klass)
 			G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
 			0,
 			NULL, NULL,
-			g_cclosure_marshal_VOID__INT,
+			cd_dbus_marshal_VOID__INT,
 			G_TYPE_NONE, 1, G_TYPE_INT);
 	s_iSignals[MIDDLE_CLIC] =
 		g_signal_new("on_middle_click",
@@ -103,7 +58,7 @@ void cd_dbus_applet_init_signals_once (dbusAppletClass *klass)
 			G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
 			0,
 			NULL, NULL,
-			g_cclosure_marshal_VOID__VOID,
+			cd_dbus_marshal_VOID__VOID,
 			G_TYPE_NONE, 0, G_TYPE_NONE);
 	s_iSignals[SCROLL] =
 		g_signal_new("on_scroll",
@@ -111,7 +66,7 @@ void cd_dbus_applet_init_signals_once (dbusAppletClass *klass)
 			G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
 			0,
 			NULL, NULL,
-			g_cclosure_marshal_VOID__BOOLEAN,
+			cd_dbus_marshal_VOID__BOOLEAN,
 			G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
 	s_iSignals[BUILD_MENU] =
 		g_signal_new("on_build_menu",
@@ -119,7 +74,7 @@ void cd_dbus_applet_init_signals_once (dbusAppletClass *klass)
 			G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
 			0,
 			NULL, NULL,
-			g_cclosure_marshal_VOID__VOID,
+			cd_dbus_marshal_VOID__VOID,
 			G_TYPE_NONE, 0, G_TYPE_NONE);
 	s_iSignals[MENU_SELECT] =
 		g_signal_new("on_menu_select",
@@ -127,7 +82,7 @@ void cd_dbus_applet_init_signals_once (dbusAppletClass *klass)
 			G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
 			0,
 			NULL, NULL,
-			g_cclosure_marshal_VOID__INT,
+			cd_dbus_marshal_VOID__INT,
 			G_TYPE_NONE, 1, G_TYPE_INT);
 	s_iSignals[DROP_DATA] =
 		g_signal_new("on_drop_data",
@@ -135,7 +90,7 @@ void cd_dbus_applet_init_signals_once (dbusAppletClass *klass)
 			G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
 			0,
 			NULL, NULL,
-			g_cclosure_marshal_VOID__STRING,
+			cd_dbus_marshal_VOID__STRING,
 			G_TYPE_NONE, 1, G_TYPE_STRING);
 	s_iSignals[CHANGE_FOCUS] =
 		g_signal_new("on_change_focus",
@@ -143,7 +98,7 @@ void cd_dbus_applet_init_signals_once (dbusAppletClass *klass)
 			G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
 			0,
 			NULL, NULL,
-			g_cclosure_marshal_VOID__BOOLEAN,
+			cd_dbus_marshal_VOID__BOOLEAN,
 			G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
 	s_iSignals[ANSWER] =
 		g_signal_new("on_answer",
@@ -151,15 +106,31 @@ void cd_dbus_applet_init_signals_once (dbusAppletClass *klass)
 			G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
 			0,
 			NULL, NULL,
-			g_cclosure_marshal_VOID__VALUE,
-			G_TYPE_NONE, 1, G_TYPE_VALUE);
+			cd_dbus_marshal_VOID__VALUE,
+			G_TYPE_NONE, 1, G_TYPE_VALUE);  // deprecated
+	s_iSignals[ANSWER_DIALOG] =
+		g_signal_new("on_answer_dialog",
+			G_OBJECT_CLASS_TYPE(klass),
+			G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
+			0,
+			NULL, NULL,
+			cd_dbus_marshal_VOID__INT_VALUE,
+			G_TYPE_NONE, 2, G_TYPE_INT, G_TYPE_VALUE);
+	s_iSignals[SHORTKEY] =
+		g_signal_new("on_shortkey",
+			G_OBJECT_CLASS_TYPE(klass),
+			G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
+			0,
+			NULL, NULL,
+			cd_dbus_marshal_VOID__STRING,
+			G_TYPE_NONE, 1, G_TYPE_STRING);
 	s_iSignals[INIT_MODULE] =
 		g_signal_new("on_init_module",
 			G_OBJECT_CLASS_TYPE(klass),
 			G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
 			0,
 			NULL, NULL,
-			g_cclosure_marshal_VOID__VOID,
+			cd_dbus_marshal_VOID__VOID,
 			G_TYPE_NONE, 0, G_TYPE_NONE);
 	s_iSignals[STOP_MODULE] =
 		g_signal_new("on_stop_module",
@@ -167,7 +138,7 @@ void cd_dbus_applet_init_signals_once (dbusAppletClass *klass)
 			G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
 			0,
 			NULL, NULL,
-			g_cclosure_marshal_VOID__VOID,
+			cd_dbus_marshal_VOID__VOID,
 			G_TYPE_NONE, 0, G_TYPE_NONE);
 	s_iSignals[RELOAD_MODULE] =
 		g_signal_new("on_reload_module",
@@ -175,7 +146,7 @@ void cd_dbus_applet_init_signals_once (dbusAppletClass *klass)
 			G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
 			0,
 			NULL, NULL,
-			g_cclosure_marshal_VOID__BOOLEAN,
+			cd_dbus_marshal_VOID__BOOLEAN,
 			G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
 	
 	// Add signals
@@ -197,6 +168,10 @@ void cd_dbus_applet_init_signals_once (dbusAppletClass *klass)
 		dbus_g_proxy_add_signal(pProxy, "on_change_focus",
 			G_TYPE_BOOLEAN, G_TYPE_INVALID);
 		dbus_g_proxy_add_signal(pProxy, "on_answer",
+			G_TYPE_VALUE, G_TYPE_INVALID);  // deprecated
+		dbus_g_proxy_add_signal(pProxy, "on_answer_dialog",
+			G_TYPE_VALUE, G_TYPE_INVALID);
+		dbus_g_proxy_add_signal(pProxy, "on_shortkey",
 			G_TYPE_VALUE, G_TYPE_INVALID);
 		dbus_g_proxy_add_signal(pProxy, "on_init_module",
 			G_TYPE_INVALID);
@@ -215,13 +190,13 @@ void cd_dbus_sub_applet_init_signals_once (dbusSubAppletClass *klass)
 	bFirst = FALSE;
 	
 	// Enregistrement des marshaller specifique aux signaux.
-	dbus_g_object_register_marshaller(g_cclosure_marshal_VOID__INT_STRING,
+	dbus_g_object_register_marshaller(cd_dbus_marshal_VOID__INT_STRING,
 		G_TYPE_NONE, G_TYPE_INT, G_TYPE_STRING, G_TYPE_INVALID);  // clic
-	dbus_g_object_register_marshaller(g_cclosure_marshal_VOID__BOOLEAN_STRING,
+	dbus_g_object_register_marshaller(cd_dbus_marshal_VOID__BOOLEAN_STRING,
 		G_TYPE_NONE, G_TYPE_BOOLEAN, G_TYPE_STRING, G_TYPE_INVALID);  // scroll
-	dbus_g_object_register_marshaller(g_cclosure_marshal_VOID__STRING_STRING,
+	dbus_g_object_register_marshaller(cd_dbus_marshal_VOID__STRING_STRING,
 		G_TYPE_NONE, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_INVALID);  // drop
-	dbus_g_object_register_marshaller(g_cclosure_marshal_VOID__VALUE_STRING,
+	dbus_g_object_register_marshaller(cd_dbus_marshal_VOID__VALUE_STRING,
 		G_TYPE_NONE, G_TYPE_VALUE, G_TYPE_STRING, G_TYPE_INVALID);  // answer
 	
 	// on definit les signaux dont on aura besoin.
@@ -231,7 +206,7 @@ void cd_dbus_sub_applet_init_signals_once (dbusSubAppletClass *klass)
 				G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
 				0,
 				NULL, NULL,
-				g_cclosure_marshal_VOID__INT_STRING,
+				cd_dbus_marshal_VOID__INT_STRING,
 				G_TYPE_NONE, 2, G_TYPE_INT, G_TYPE_STRING);
 	s_iSubSignals[MIDDLE_CLIC] =
 		g_signal_new("on_middle_click_sub_icon",
@@ -239,7 +214,7 @@ void cd_dbus_sub_applet_init_signals_once (dbusSubAppletClass *klass)
 				G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
 				0,
 				NULL, NULL,
-				g_cclosure_marshal_VOID__STRING,
+				cd_dbus_marshal_VOID__STRING,
 				G_TYPE_NONE, 1, G_TYPE_STRING);
 	s_iSubSignals[SCROLL] =
 		g_signal_new("on_scroll_sub_icon",
@@ -247,7 +222,7 @@ void cd_dbus_sub_applet_init_signals_once (dbusSubAppletClass *klass)
 				G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
 				0,
 				NULL, NULL,
-				g_cclosure_marshal_VOID__BOOLEAN_STRING,
+				cd_dbus_marshal_VOID__BOOLEAN_STRING,
 				G_TYPE_NONE, 2, G_TYPE_BOOLEAN, G_TYPE_STRING);
 	s_iSubSignals[BUILD_MENU] =
 		g_signal_new("on_build_menu_sub_icon",
@@ -255,32 +230,16 @@ void cd_dbus_sub_applet_init_signals_once (dbusSubAppletClass *klass)
 				G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
 				0,
 				NULL, NULL,
-				g_cclosure_marshal_VOID__STRING,
+				cd_dbus_marshal_VOID__STRING,
 				G_TYPE_NONE, 1, G_TYPE_STRING);
-	s_iSubSignals[MENU_SELECT] =
-		g_signal_new("on_menu_select_sub_icon",
-			G_OBJECT_CLASS_TYPE(klass),
-				G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
-				0,
-				NULL, NULL,
-				g_cclosure_marshal_VOID__INT_STRING,
-				G_TYPE_NONE, 2, G_TYPE_INT, G_TYPE_STRING);
 	s_iSubSignals[DROP_DATA] =
 		g_signal_new("on_drop_data_sub_icon",
 			G_OBJECT_CLASS_TYPE(klass),
 				G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
 				0,
 				NULL, NULL,
-				g_cclosure_marshal_VOID__STRING_STRING,
+				cd_dbus_marshal_VOID__STRING_STRING,
 				G_TYPE_NONE, 2, G_TYPE_STRING, G_TYPE_STRING);
-	s_iSubSignals[ANSWER] =
-		g_signal_new("on_answer_sub_icon",
-			G_OBJECT_CLASS_TYPE(klass),
-				G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
-				0,
-				NULL, NULL,
-				g_cclosure_marshal_VOID__VALUE_STRING,
-				G_TYPE_NONE, 2, G_TYPE_VALUE, G_TYPE_STRING);
 	
 	// Add signals
 	DBusGProxy *pProxy = cairo_dock_get_main_proxy ();
@@ -294,16 +253,12 @@ void cd_dbus_sub_applet_init_signals_once (dbusSubAppletClass *klass)
 			G_TYPE_BOOLEAN, G_TYPE_STRING, G_TYPE_INVALID);
 		dbus_g_proxy_add_signal(pProxy, "on_build_menu_sub_icon",
 			G_TYPE_STRING, G_TYPE_INVALID);
-		dbus_g_proxy_add_signal(pProxy, "on_menu_select_sub_icon",
-			G_TYPE_INT, G_TYPE_STRING, G_TYPE_INVALID);
 		dbus_g_proxy_add_signal(pProxy, "on_drop_data_sub_icon",
 			G_TYPE_STRING, G_TYPE_STRING, G_TYPE_INVALID);
-		dbus_g_proxy_add_signal(pProxy, "on_answer_sub_icon",
-			G_TYPE_VALUE, G_TYPE_STRING, G_TYPE_INVALID);
 	}
 }
 
-#define CAIRO_DOCK_IS_MANUAL_APPLET(pIcon) (CAIRO_DOCK_IS_APPLET (pIcon) && pIcon->pModuleInstance->pModule->cSoFilePath == NULL)
+#define CAIRO_DOCK_IS_EXTERNAL_APPLET(pIcon) (CAIRO_DOCK_IS_APPLET (pIcon) && pIcon->pModuleInstance->pModule->cSoFilePath == NULL)
 
 static inline Icon *_get_main_icon_from_clicked_icon (Icon *pIcon, CairoContainer *pContainer)
 {
@@ -331,21 +286,21 @@ gboolean cd_dbus_applet_emit_on_click_icon (gpointer data, Icon *pClickedIcon, C
 	if (pClickedIcon == NULL)
 		return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 	Icon *pAppletIcon = _get_main_icon_from_clicked_icon (pClickedIcon, pClickedContainer);
-	if (! CAIRO_DOCK_IS_MANUAL_APPLET (pAppletIcon))
+	if (! CAIRO_DOCK_IS_EXTERNAL_APPLET (pAppletIcon))
 		return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 	
-	g_print ("%s (%s, %d)\n", __func__, pAppletIcon->pModuleInstance->pModule->pVisitCard->cModuleName, iButtonState);
+	//g_print ("%s (%s, %d)\n", __func__, pAppletIcon->pModuleInstance->pModule->pVisitCard->cModuleName, iButtonState);
 	dbusApplet *pDbusApplet = cd_dbus_get_dbus_applet_from_instance (pAppletIcon->pModuleInstance);
 	g_return_val_if_fail (pDbusApplet != NULL, CAIRO_DOCK_LET_PASS_NOTIFICATION);
 	
 	if (pClickedIcon == pAppletIcon)
 	{
-		g_print ("emit clic on main icon\n");
+		//g_print ("emit clic on main icon\n");
 		g_signal_emit (pDbusApplet, s_iSignals[CLIC], 0, iButtonState);
 	}
 	else if (pDbusApplet->pSubApplet != NULL)
 	{
-		g_print ("emit clic on sub icon\n");
+		//g_print ("emit clic on sub icon\n");
 		g_signal_emit (pDbusApplet->pSubApplet, s_iSubSignals[CLIC], 0, iButtonState, pClickedIcon->cCommand);
 	}
 	return CAIRO_DOCK_INTERCEPT_NOTIFICATION;
@@ -356,10 +311,10 @@ gboolean cd_dbus_applet_emit_on_middle_click_icon (gpointer data, Icon *pClicked
 	if (pClickedIcon == NULL)
 		return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 	Icon *pAppletIcon = _get_main_icon_from_clicked_icon (pClickedIcon, pClickedContainer);
-	if (! CAIRO_DOCK_IS_MANUAL_APPLET (pAppletIcon))
+	if (! CAIRO_DOCK_IS_EXTERNAL_APPLET (pAppletIcon))
 		return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 	
-	g_print ("%s (%s)\n", __func__, pAppletIcon->pModuleInstance->pModule->pVisitCard->cModuleName);
+	//g_print ("%s (%s)\n", __func__, pAppletIcon->pModuleInstance->pModule->pVisitCard->cModuleName);
 	dbusApplet *pDbusApplet = cd_dbus_get_dbus_applet_from_instance (pAppletIcon->pModuleInstance);
 	g_return_val_if_fail (pDbusApplet != NULL, CAIRO_DOCK_LET_PASS_NOTIFICATION);
 	
@@ -375,10 +330,10 @@ gboolean cd_dbus_applet_emit_on_scroll_icon (gpointer data, Icon *pClickedIcon,
 	if (pClickedIcon == NULL)
 		return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 	Icon *pAppletIcon = _get_main_icon_from_clicked_icon (pClickedIcon, pClickedContainer);
-	if (! CAIRO_DOCK_IS_MANUAL_APPLET (pAppletIcon))
+	if (! CAIRO_DOCK_IS_EXTERNAL_APPLET (pAppletIcon))
 		return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 	
-	g_print ("%s (%s, %d)\n", __func__, pAppletIcon->pModuleInstance->pModule->pVisitCard->cModuleName, iDirection);
+	//g_print ("%s (%s, %d)\n", __func__, pAppletIcon->pModuleInstance->pModule->pVisitCard->cModuleName, iDirection);
 	dbusApplet *pDbusApplet = cd_dbus_get_dbus_applet_from_instance (pAppletIcon->pModuleInstance);
 	g_return_val_if_fail (pDbusApplet != NULL, CAIRO_DOCK_LET_PASS_NOTIFICATION);
 	
@@ -399,7 +354,7 @@ gboolean cd_dbus_applet_emit_on_build_menu (gpointer data, Icon *pClickedIcon, C
 	if (pClickedIcon == NULL)
 		return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 	Icon *pAppletIcon = _get_main_icon_from_clicked_icon (pClickedIcon, pClickedContainer);
-	if (! CAIRO_DOCK_IS_MANUAL_APPLET (pAppletIcon))
+	if (! CAIRO_DOCK_IS_EXTERNAL_APPLET (pAppletIcon))
 		return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 	
 	myData.pModuleMainMenu = pAppletMenu;
@@ -407,7 +362,7 @@ gboolean cd_dbus_applet_emit_on_build_menu (gpointer data, Icon *pClickedIcon, C
 		pAppletMenu,
 		pAppletIcon->pModuleInstance->pModule->pVisitCard->cIconFilePath);
 	
-	cairo_dock_add_in_menu_with_stock_and_data (_("About this applet"),
+	cairo_dock_add_in_menu_with_stock_and_data (_("Applet's handbook"),
 		GTK_STOCK_ABOUT,
 		(GFunc) cairo_dock_pop_up_about_applet,
 		myData.pModuleSubMenu,
@@ -418,11 +373,10 @@ gboolean cd_dbus_applet_emit_on_build_menu (gpointer data, Icon *pClickedIcon, C
 		G_CALLBACK (_delete_menu),
 		myApplet);
 	
-	g_print ("%s (%s)\n", __func__, pAppletIcon->pModuleInstance->pModule->pVisitCard->cModuleName);
+	//g_print ("%s (%s)\n", __func__, pAppletIcon->pModuleInstance->pModule->pVisitCard->cModuleName);
 	dbusApplet *pDbusApplet = cd_dbus_get_dbus_applet_from_instance (pAppletIcon->pModuleInstance);
 	g_return_val_if_fail (pDbusApplet != NULL, CAIRO_DOCK_LET_PASS_NOTIFICATION);
 	myData.pCurrentMenuDbusApplet = pDbusApplet;
-	myData.pCurrentMenuIcon = pClickedIcon;
 	
 	if (pClickedIcon == pAppletIcon)
 		g_signal_emit (pDbusApplet, s_iSignals[BUILD_MENU], 0);
@@ -431,28 +385,30 @@ gboolean cd_dbus_applet_emit_on_build_menu (gpointer data, Icon *pClickedIcon, C
 	return (pClickedIcon == pAppletIcon ? CAIRO_DOCK_LET_PASS_NOTIFICATION : CAIRO_DOCK_INTERCEPT_NOTIFICATION);
 }
 
-void cd_dbus_emit_on_menu_select (GtkMenuShell *menu, gpointer data)
+void cd_dbus_emit_on_menu_select (GtkMenuItem *pMenuItem, gpointer data)
 {
-	g_return_if_fail (myData.pCurrentMenuIcon != NULL);
+	g_return_if_fail (myData.pCurrentMenuDbusApplet != NULL);
+	if (GTK_IS_RADIO_MENU_ITEM (pMenuItem))
+	{
+		if (!gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (pMenuItem)))
+			return ;
+	}
+	
 	int iNumEntry = GPOINTER_TO_INT (data);
-	gchar *cIconID = myData.pCurrentMenuIcon->cCommand;  // NULL si c'est l'icone principale.
-	if (cIconID == NULL)
-		g_signal_emit (myData.pCurrentMenuDbusApplet, s_iSignals[MENU_SELECT], 0, iNumEntry);
-	else if (myData.pCurrentMenuDbusApplet->pSubApplet != NULL)
-		g_signal_emit (myData.pCurrentMenuDbusApplet->pSubApplet, s_iSubSignals[MENU_SELECT], 0, iNumEntry, cIconID);
+	g_signal_emit (myData.pCurrentMenuDbusApplet, s_iSignals[MENU_SELECT], 0, iNumEntry);  // since there can only be 1 menu at once, and the applet knows when the menu is raised, there is no need to pass the icon in the signal: the applet can remember the clicked icon when it received the 'build-menu' event.
 }
 
 gboolean cd_dbus_applet_emit_on_drop_data (gpointer data, const gchar *cReceivedData, Icon *pClickedIcon, double fPosition, CairoContainer *pClickedContainer)
 {
 	//\________________ On gere le cas d'une applet tierce-partie en provenance de nos depots.
-	if (cReceivedData && strncmp (cReceivedData, "http://", 7) == 0 && g_str_has_suffix (cReceivedData, ".tar.gz") && (g_strstr_len (cReceivedData, -1, "cairo-dock") || g_strstr_len (cReceivedData, -1, "glx-dock")))
+	if (cReceivedData && strncmp (cReceivedData, "http://", 7) == 0 && g_str_has_suffix (cReceivedData, ".tar.gz") && (g_strstr_len (cReceivedData, -1, "glxdock") || g_strstr_len (cReceivedData, -1, "glx-dock")))
 	{
 		//\________________ On telecharge l'archive de l'applet et on l'installe/la met a jour.
 		GError *erreur = NULL;
-		g_print ("dropped a distant applet\n");
+		//g_print ("dropped a distant applet\n");
 		gchar *cServerAdress = g_path_get_dirname (cReceivedData);
 		gchar *cDistantFileName = g_path_get_basename (cReceivedData);
-		gchar *cExtractTo = g_strdup_printf ("%s/third-party", g_cCairoDockDataDir);
+		gchar *cExtractTo = g_strdup_printf ("%s/%s", g_cCairoDockDataDir, CD_DBUS_APPLETS_FOLDER);
 		gchar *cAppletDirPath = cairo_dock_download_file (cServerAdress, "", cDistantFileName, cExtractTo, &erreur);
 		g_free (cServerAdress);
 		g_free (cDistantFileName);
@@ -461,6 +417,10 @@ gboolean cd_dbus_applet_emit_on_drop_data (gpointer data, const gchar *cReceived
 			cd_warning (erreur->message);
 			g_error_free (erreur);
 		}
+		if (cAppletDirPath == NULL)
+		{
+			cairo_dock_show_general_message (D_("Sorry, this module couldn't be added."), 10000);
+		}
 		else
 		{
 			//\________________ On la supprime totalement si elle existe deja (mise a jour).
@@ -482,27 +442,28 @@ gboolean cd_dbus_applet_emit_on_drop_data (gpointer data, const gchar *cReceived
 			}
 			
 			//\________________ On l'enregistre et on la (re)lance.
-			cd_dbus_add_applet_to_startup (cAppletName);
 			cd_dbus_register_module_in_dir (cAppletName, cExtractTo);
 			
+			cairo_dock_activate_module_and_load (cAppletName);
+			
 			//\________________ On balance un petit message a l'utilisateur.
 			pModule = cairo_dock_find_module_from_name (cAppletName);
 			if (!pModule)
 			{
-				cairo_dock_show_general_message (_("Sorry, this module couldn't be added."), 10000);
+				cairo_dock_show_general_message (D_("Sorry, this module couldn't be added."), 10000);
 			}
 			else if (!pModule->pInstancesList)
 			{
-				cairo_dock_show_general_message (_("The module has been added, but couldn't be launched."), 10000);
+				cairo_dock_show_general_message (D_("The module has been added, but couldn't be launched."), 10000);
 			}
 			else
 			{
 				CairoDockModuleInstance *pInstance = pModule->pInstancesList->data;
 				if (!pInstance->pIcon || !pInstance->pContainer)
-					cairo_dock_show_general_message (_("The module has been added, but couldn't be launched."), 10000);
+					cairo_dock_show_general_message (D_("The module has been added, but couldn't be launched."), 10000);
 				else
 				{
-					cairo_dock_show_temporary_dialog_with_icon_printf (bUpdate ? _("The applet '%s' has been succefully updated and automatically reloaded") : _("The applet '%s' has been succefully installed and automatically launched"),
+					cairo_dock_show_temporary_dialog_with_icon_printf (bUpdate ? D_("The applet '%s' has been succefully updated and automatically reloaded") : D_("The applet '%s' has been succefully installed and automatically launched"),
 						pInstance->pIcon,
 						pInstance->pContainer,
 						10000,
@@ -518,10 +479,10 @@ gboolean cd_dbus_applet_emit_on_drop_data (gpointer data, const gchar *cReceived
 	
 	//\________________ Sinon on notifie l'applet du drop.
 	Icon *pAppletIcon = _get_main_icon_from_clicked_icon (pClickedIcon, pClickedContainer);
-	if (! CAIRO_DOCK_IS_MANUAL_APPLET (pAppletIcon))
+	if (! CAIRO_DOCK_IS_EXTERNAL_APPLET (pAppletIcon))
 		return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 	
-	cd_message (" %s --> sur le bus !", cReceivedData);
+	cd_debug (" %s --> sur le bus !", cReceivedData);
 	dbusApplet *pDbusApplet = cd_dbus_get_dbus_applet_from_instance (pAppletIcon->pModuleInstance);
 	g_return_val_if_fail (pDbusApplet != NULL, CAIRO_DOCK_LET_PASS_NOTIFICATION);
 	
@@ -540,8 +501,8 @@ gboolean cd_dbus_applet_emit_on_change_focus (gpointer data, Window *xNewActiveW
 	{
 		Icon *pPrevActiveIcon = cairo_dock_get_icon_with_Xid (myData.xActiveWindow);
 		if (pPrevActiveIcon && pPrevActiveIcon->cParentDockName == NULL)
-			pPrevActiveIcon = cairo_dock_get_inhibator (pPrevActiveIcon, FALSE);
-		if (CAIRO_DOCK_IS_MANUAL_APPLET (pPrevActiveIcon))
+			pPrevActiveIcon = cairo_dock_get_inhibitor (pPrevActiveIcon, FALSE);
+		if (CAIRO_DOCK_IS_EXTERNAL_APPLET (pPrevActiveIcon))
 		{
 			dbusApplet *pDbusApplet = cd_dbus_get_dbus_applet_from_instance (pPrevActiveIcon->pModuleInstance);
 			g_return_val_if_fail (pDbusApplet != NULL, CAIRO_DOCK_LET_PASS_NOTIFICATION);
@@ -550,12 +511,13 @@ gboolean cd_dbus_applet_emit_on_change_focus (gpointer data, Window *xNewActiveW
 	}
 	
 	// on emet le signal sur l'icone qui a desormais le focus.
+	//g_print ("DBUS : new active window : %ld\n", *xNewActiveWindow);
 	if (*xNewActiveWindow != 0)
 	{
 		Icon *pNewActiveIcon = cairo_dock_get_icon_with_Xid (*xNewActiveWindow);
 		if (pNewActiveIcon && pNewActiveIcon->cParentDockName == NULL)
-			pNewActiveIcon = cairo_dock_get_inhibator (pNewActiveIcon, FALSE);
-		if (CAIRO_DOCK_IS_MANUAL_APPLET (pNewActiveIcon))
+			pNewActiveIcon = cairo_dock_get_inhibitor (pNewActiveIcon, FALSE);
+		if (CAIRO_DOCK_IS_EXTERNAL_APPLET (pNewActiveIcon))
 		{
 			dbusApplet *pDbusApplet = cd_dbus_get_dbus_applet_from_instance (pNewActiveIcon->pModuleInstance);
 			g_return_val_if_fail (pDbusApplet != NULL, CAIRO_DOCK_LET_PASS_NOTIFICATION);
@@ -568,22 +530,17 @@ gboolean cd_dbus_applet_emit_on_change_focus (gpointer data, Window *xNewActiveW
 }
 
 
+// deprecated
 static inline void _emit_answer (dbusApplet *pDbusApplet, CairoDialog *pDialog, GValue *v)
 {
-	Icon *pClickedIcon = pDialog->pIcon;
-	Icon *pAppletIcon = pDbusApplet->pModuleInstance->pIcon;
-	
-	if (pClickedIcon == pAppletIcon)
-		g_signal_emit (pDbusApplet, s_iSignals[ANSWER], 0, v);
-	else if (pDbusApplet->pSubApplet != NULL)
-		g_signal_emit (pDbusApplet->pSubApplet, s_iSubSignals[ANSWER], 0, v, pClickedIcon->cCommand);
+	g_signal_emit (pDbusApplet, s_iSignals[ANSWER], 0, v);  // same remark as for the menu: 1 dialog at once, the applet knows when the dialog is raised, so it can just remember the clicked icon; we don't need to tell it.
 	
 	pDbusApplet->pDialog = NULL;
 }
 void cd_dbus_applet_emit_on_answer_question (int iClickedButton, GtkWidget *pInteractiveWidget, dbusApplet *pDbusApplet, CairoDialog *pDialog)
 {
 	gboolean bYes = (iClickedButton == 0 || iClickedButton == -1);
-	GValue v = {0,};
+	GValue v = G_VALUE_INIT;
 	g_value_init (&v, G_TYPE_BOOLEAN);
 	g_value_set_boolean (&v, bYes);
 	
@@ -593,7 +550,7 @@ void cd_dbus_applet_emit_on_answer_question (int iClickedButton, GtkWidget *pInt
 void cd_dbus_applet_emit_on_answer_value (int iClickedButton, GtkWidget *pInteractiveWidget, dbusApplet *pDbusApplet, CairoDialog *pDialog)
 {
 	double fValue = (iClickedButton == 0 || iClickedButton == -1 ? gtk_range_get_value (GTK_RANGE (pInteractiveWidget)) : -1);
-	GValue v = {0,};
+	GValue v = G_VALUE_INIT;
 	g_value_init (&v, G_TYPE_DOUBLE);
 	g_value_set_double (&v, fValue);
 	
@@ -603,12 +560,137 @@ void cd_dbus_applet_emit_on_answer_value (int iClickedButton, GtkWidget *pIntera
 void cd_dbus_applet_emit_on_answer_text (int iClickedButton, GtkWidget *pInteractiveWidget, dbusApplet *pDbusApplet, CairoDialog *pDialog)
 {
 	const gchar *cAnswer = (iClickedButton == 0 || iClickedButton == -1 ? gtk_entry_get_text (GTK_ENTRY (pInteractiveWidget)) : NULL);
-	GValue v = {0,};
+	GValue v = G_VALUE_INIT;
 	g_value_init (&v, G_TYPE_STRING);
 	g_value_set_string (&v, cAnswer);
 	
 	_emit_answer (pDbusApplet, pDialog, &v);
 }
+// end of deprecated
+
+
+static inline void _emit_answer_dialog (dbusApplet *pDbusApplet, CairoDialog *pDialog, int iClickedButton, GValue *v)
+{
+	g_signal_emit (pDbusApplet, s_iSignals[ANSWER_DIALOG], 0, iClickedButton, v);  // same remark as for the menu: 1 dialog at once, the applet knows when the dialog is raised, so it can just remember the clicked icon; we don't need to tell it.
+	
+	pDbusApplet->pDialog = NULL;
+}
+void cd_dbus_applet_emit_on_answer_buttons (int iClickedButton, GtkWidget *pInteractiveWidget, dbusApplet *pDbusApplet, CairoDialog *pDialog)
+{
+	GValue v = G_VALUE_INIT;
+	g_value_init (&v, G_TYPE_INT);
+	g_value_set_int (&v, iClickedButton);
+	
+	_emit_answer_dialog (pDbusApplet, pDialog, iClickedButton, &v);
+}
+
+void cd_dbus_applet_emit_on_answer_text_entry (int iClickedButton, GtkWidget *pInteractiveWidget, dbusApplet *pDbusApplet, CairoDialog *pDialog)
+{
+	GValue v = G_VALUE_INIT;
+	g_value_init (&v, G_TYPE_STRING);
+	
+	GtkWidget *pEntry = g_object_get_data (G_OBJECT (pInteractiveWidget), "cd-widget");
+	g_return_if_fail (pEntry != NULL);
+	/**GtkWidget *pEntry;
+	if (GTK_IS_ENTRY (pInteractiveWidget))
+	{
+		pEntry = pInteractiveWidget;
+	}
+	else
+	{
+		GList *children = gtk_container_get_children (GTK_CONTAINER (pInteractiveWidget));
+		g_return_if_fail (children != NULL);
+		pEntry = children->data;
+	}*/
+	
+	const gchar *cText = gtk_entry_get_text (GTK_ENTRY (pEntry));
+	//g_print (" -> %s\n", cText);
+	g_value_set_string (&v, cText);
+	_emit_answer_dialog (pDbusApplet, pDialog, iClickedButton, &v);
+}
+
+void cd_dbus_applet_emit_on_answer_text_view (int iClickedButton, GtkWidget *pInteractiveWidget, dbusApplet *pDbusApplet, CairoDialog *pDialog)
+{
+	GValue v = G_VALUE_INIT;
+	g_value_init (&v, G_TYPE_STRING);
+	
+	GtkWidget *pTextView = g_object_get_data (G_OBJECT (pInteractiveWidget), "cd-widget");
+	g_return_if_fail (pTextView != NULL);
+	/**if (GTK_IS_TEXT_VIEW (pInteractiveWidget))
+	{
+		pTextView = pInteractiveWidget;
+	}
+	else
+	{
+		GList *children = gtk_container_get_children (GTK_CONTAINER (pInteractiveWidget));
+		g_return_if_fail (children != NULL);
+		pTextView = children->data;
+	}*/
+	GtkTextBuffer *pBuffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (pTextView));
+	GtkTextIter start, end;
+	gtk_text_buffer_get_start_iter (pBuffer, &start);
+	gtk_text_buffer_get_end_iter (pBuffer, &end);
+	gchar *cText = gtk_text_buffer_get_text (pBuffer,
+		&start,
+		&end,
+		FALSE);
+	
+	g_value_set_string (&v, cText);
+	_emit_answer_dialog (pDbusApplet, pDialog, iClickedButton, &v);
+	g_free (cText);
+}
+
+void cd_dbus_applet_emit_on_answer_scale (int iClickedButton, GtkWidget *pInteractiveWidget, dbusApplet *pDbusApplet, CairoDialog *pDialog)
+{
+	GValue v = G_VALUE_INIT;
+	g_value_init (&v, G_TYPE_DOUBLE);
+	
+	GtkWidget *pScale = g_object_get_data (G_OBJECT (pInteractiveWidget), "cd-widget");
+	g_return_if_fail (pScale != NULL);
+	/**GtkWidget *pScale;
+	if (GTK_IS_RANGE (pInteractiveWidget))
+	{
+		pScale = pInteractiveWidget;
+	}
+	else
+	{
+		GList *children = gtk_container_get_children (GTK_CONTAINER (pInteractiveWidget));
+		g_return_if_fail (children != NULL && children->next != NULL);
+		pScale = children->next->data;
+	}*/
+	
+	double x = gtk_range_get_value (GTK_RANGE (pScale));
+	g_value_set_double (&v, x);
+	_emit_answer_dialog (pDbusApplet, pDialog, iClickedButton, &v);
+}
+
+void cd_dbus_applet_emit_on_answer_combo_entry (int iClickedButton, GtkWidget *pInteractiveWidget, dbusApplet *pDbusApplet, CairoDialog *pDialog)
+{
+	GValue v = G_VALUE_INIT;
+	g_value_init (&v, G_TYPE_STRING);
+	
+	GtkWidget *pEntry = gtk_bin_get_child (GTK_BIN (pInteractiveWidget));
+	const gchar *cText = gtk_entry_get_text (GTK_ENTRY (pEntry));
+	
+	g_value_set_string (&v, cText);
+	_emit_answer_dialog (pDbusApplet, pDialog, iClickedButton, &v);
+}
+
+void cd_dbus_applet_emit_on_answer_combo (int iClickedButton, GtkWidget *pInteractiveWidget, dbusApplet *pDbusApplet, CairoDialog *pDialog)
+{
+	GValue v = G_VALUE_INIT;
+	g_value_init (&v, G_TYPE_INT);
+	
+	int iSelectedItem = gtk_combo_box_get_active (GTK_COMBO_BOX (pInteractiveWidget));
+	
+	g_value_set_int (&v, iSelectedItem);
+	_emit_answer_dialog (pDbusApplet, pDialog, iClickedButton, &v);
+}
+
+void cd_dbus_applet_emit_on_shortkey (const gchar *cShortkey, dbusApplet *pDbusApplet)
+{
+	g_signal_emit (pDbusApplet, s_iSignals[SHORTKEY], 0, cShortkey);
+}
 
 
 void cd_dbus_action_on_init_module (CairoDockModuleInstance *pModuleInstance)
@@ -618,8 +700,6 @@ void cd_dbus_action_on_init_module (CairoDockModuleInstance *pModuleInstance)
 	{
 		cairo_dock_set_desklet_renderer_by_name (pModuleInstance->pDesklet,
 			"Simple",
-			NULL,
-			CAIRO_DOCK_LOAD_ICONS_FOR_DESKLET,
 			(CairoDeskletRendererConfigPtr) NULL);
 	}
 	
@@ -638,7 +718,7 @@ void cd_dbus_action_on_stop_module (CairoDockModuleInstance *pModuleInstance)
 {
 	if (pModuleInstance->pIcon->pSubDock != NULL)
 	{
-		cairo_dock_destroy_dock (pModuleInstance->pIcon->pSubDock, pModuleInstance->pIcon->cName, NULL, NULL);
+		cairo_dock_destroy_dock (pModuleInstance->pIcon->pSubDock, pModuleInstance->pIcon->cName);
 		pModuleInstance->pIcon->pSubDock = NULL;
 	}
 	
@@ -652,18 +732,9 @@ void cd_dbus_action_on_stop_module (CairoDockModuleInstance *pModuleInstance)
 	}
 }
 
-static gboolean _update_active_applets_in_conf (gpointer data)
-{
-	cairo_dock_update_conf_file (CD_APPLET_MY_CONF_FILE,
-		G_TYPE_STRING, "Configuration", "modules", myData.cActiveModules,
-		G_TYPE_INVALID);
-	myData.iSidRemoveAppletFromConf = 0;
-	return FALSE;
-}
-
 void cd_dbus_emit_on_stop_module (CairoDockModuleInstance *pModuleInstance)
 {
-	g_print ("%s (%s, %d)\n", __func__, pModuleInstance->pModule->pVisitCard->cModuleName, myData.bServiceIsStopping);
+	//g_print ("%s (%s, %d)\n", __func__, pModuleInstance->pModule->pVisitCard->cModuleName, myData.bKeepObjectAlive);
 	dbusApplet *pDbusApplet = cd_dbus_get_dbus_applet_from_instance (pModuleInstance);
 	if (pDbusApplet != NULL)
 		g_signal_emit (pDbusApplet,
@@ -673,28 +744,12 @@ void cd_dbus_emit_on_stop_module (CairoDockModuleInstance *pModuleInstance)
 		
 	cd_dbus_action_on_stop_module (pModuleInstance);
 	
-	// on enleve le nom de myData.cActiveModules si c'est une desactivation par l'utilisateur (plutot que le plug-in DBus qui s'arrete).
-	if (myData.cActiveModules != NULL && ! myData.bServiceIsStopping)
-	{
-		gchar *str = g_strstr_len (myData.cActiveModules, -1, pModuleInstance->pModule->pVisitCard->cModuleName);
-		if (str)
-		{
-			*str = '\0';
-			gchar *ptr = myData.cActiveModules;
-			myData.cActiveModules = g_strdup_printf ("%s%s", myData.cActiveModules, str + strlen (pModuleInstance->pModule->pVisitCard->cModuleName));
-			g_free (ptr);
-			if (myData.iSidRemoveAppletFromConf == 0)
-				myData.iSidRemoveAppletFromConf = g_idle_add ((GSourceFunc) _update_active_applets_in_conf, NULL);  // on differe la mise a jour du fichier de conf, pour le cas ou l'applet serait desactivee par le dock a la fermeture, avant la desactivation de Dbus.
-		}
-	}
-	
-	if (! myData.bServiceIsStopping)  // on detruit l'objet a la fin.
-		cd_dbus_delete_remote_applet_object (pModuleInstance);
+	cd_dbus_delete_remote_applet_object (pDbusApplet);
 }
 
 gboolean cd_dbus_emit_on_reload_module (CairoDockModuleInstance *pModuleInstance, CairoContainer *pOldContainer, GKeyFile *pKeyFile)
 {
-	g_print ("%s ()\n", __func__);
+	//g_print ("%s ()\n", __func__);
 	CairoDockVisitCard *pVisitCard = pModuleInstance->pModule->pVisitCard;
 	dbusApplet *pDbusApplet = cd_dbus_get_dbus_applet_from_instance (pModuleInstance);
 	g_return_val_if_fail (pDbusApplet != NULL, FALSE);
@@ -709,8 +764,6 @@ gboolean cd_dbus_emit_on_reload_module (CairoDockModuleInstance *pModuleInstance
 		{
 			cairo_dock_set_desklet_renderer_by_name (pModuleInstance->pDesklet,
 				"Simple",
-				NULL,
-				CAIRO_DOCK_LOAD_ICONS_FOR_DESKLET,
 				(CairoDeskletRendererConfigPtr) NULL);
 		}
 		else
@@ -718,8 +771,6 @@ gboolean cd_dbus_emit_on_reload_module (CairoDockModuleInstance *pModuleInstance
 			gpointer data[2] = {GINT_TO_POINTER (TRUE), GINT_TO_POINTER (FALSE)};
 			cairo_dock_set_desklet_renderer_by_name (pModuleInstance->pDesklet,
 				"Caroussel",
-				NULL,
-				CAIRO_DOCK_LOAD_ICONS_FOR_DESKLET,
 				(CairoDeskletRendererConfigPtr) data);
 		}
 	}
@@ -737,15 +788,15 @@ gboolean cd_dbus_emit_on_reload_module (CairoDockModuleInstance *pModuleInstance
 	{
 		if (pIcon && pIcon->pDataRenderer != NULL)
 		{
-			cairo_t *pDrawContext = cairo_create (pIcon->pIconBuffer);
-			cairo_dock_reload_data_renderer_on_icon (pIcon, pModuleInstance->pContainer, pDrawContext, NULL);
+			cairo_dock_reload_data_renderer_on_icon (pIcon, pModuleInstance->pContainer, NULL);
 			
 			CairoDataRenderer *pRenderer = pIcon->pDataRenderer;
 			CairoDataToRenderer *pData = cairo_data_renderer_get_data (pRenderer);
-			g_print ("actuellement %d valeurs dans l'historique\n", pData->iMemorySize);
+			//g_print ("actuellement %d valeurs dans l'historique\n", pData->iMemorySize);
 			if (pData->iMemorySize > 2)
 				cairo_dock_resize_data_renderer_history (pIcon, pIcon->fWidth);
 			
+			cairo_t *pDrawContext = cairo_create (pIcon->pIconBuffer);
 			cairo_dock_refresh_data_renderer (pIcon, pModuleInstance->pContainer, pDrawContext);
 			cairo_destroy (pDrawContext);
 		}
