@@ -91,7 +91,7 @@ void cd_do_render_cairo (CairoDock *pMainDock, cairo_t *pCairoContext)
 	
 	if (myData.pCharList == NULL && myData.pListingHistory == NULL)  // aucune lettre de tapee => on montre le prompt.
 	{
-		if (! myData.bNavigationMode && myData.pPromptSurface != NULL)
+		if (myData.pPromptSurface != NULL)
 		{
 			double fFrameWidth = myData.iPromptWidth;
 			double fFrameHeight = myData.iPromptHeight;
@@ -105,30 +105,11 @@ void cd_do_render_cairo (CairoDock *pMainDock, cairo_t *pCairoContext)
 			if (fAlpha != 0)
 			{
 				cairo_translate (pCairoContext, fDockOffsetX, fDockOffsetY);
-				cairo_dock_draw_surface (pCairoContext, myData.pArrowSurface, fFrameWidth, fFrameHeight, pMainDock->container.bDirectionUp, pMainDock->container.bIsHorizontal, fAlpha);
+				cairo_dock_draw_surface (pCairoContext, myData.pPromptSurface, fFrameWidth, fFrameHeight, pMainDock->container.bDirectionUp, pMainDock->container.bIsHorizontal, fAlpha);
 				//cairo_set_source_surface (pCairoContext, myData.pPromptSurface, 0., 0.);
 				//cairo_paint_with_alpha (pCairoContext, fAlpha);
 			}
 		}
-		else if (myData.bNavigationMode && myData.pArrowSurface != NULL)
-		{
-			double fFrameWidth = myData.iArrowWidth;
-			double fFrameHeight = myData.iArrowHeight;
-			
-			double fDockOffsetX, fDockOffsetY;  // Offset du coin haut gauche du prompt.
-			fDockOffsetX = (pMainDock->container.iWidth - fFrameWidth) / 2;
-			fDockOffsetY = (pMainDock->container.iHeight - fFrameHeight) / 2;
-			
-			fAlpha *= _alpha_prompt (myData.iPromptAnimationCount, s_iNbPromptAnimationSteps);
-			
-			if (fAlpha != 0)
-			{
-				cairo_translate (pCairoContext, fDockOffsetX, fDockOffsetY);
-				cairo_dock_draw_surface (pCairoContext, myData.pArrowSurface, fFrameWidth, fFrameHeight, pMainDock->container.bDirectionUp, pMainDock->container.bIsHorizontal, fAlpha);
-				//cairo_set_source_surface (pCairoContext, myData.pArrowSurface, 0., 0.);
-				//cairo_paint_with_alpha (pCairoContext, fAlpha);
-			}
-		}
 	}
 	else  // si du texte a ete entre, on le dessine, ainsi que eventuellement la liste des icones correspondantes.
 	{
@@ -282,7 +263,7 @@ void cd_do_render_opengl (CairoDock *pMainDock)
 	
 	if (myData.pCharList == NULL && myData.pListingHistory == NULL)  // aucune lettre de tapee => on montre le prompt.
 	{
-		if (! myData.bNavigationMode && myData.iPromptTexture != 0)
+		if (myData.iPromptTexture != 0)
 		{
 			double fFrameWidth = myData.iPromptWidth;
 			double fFrameHeight = myData.iPromptHeight;
@@ -307,34 +288,6 @@ void cd_do_render_opengl (CairoDock *pMainDock)
 				
 				_cairo_dock_disable_texture ();
 				
-				glPopMatrix();
-			}
-		}
-		else if (myData.bNavigationMode && myData.iArrowTexture != 0)
-		{
-			double fFrameWidth = myData.iArrowWidth;
-			double fFrameHeight = myData.iArrowHeight;
-						
-			double fDockOffsetX, fDockOffsetY;  // Offset du coin haut gauche du prompt.
-			fDockOffsetX = (pMainDock->container.iWidth - fFrameWidth) / 2;
-			fDockOffsetY = (pMainDock->container.iHeight - fFrameHeight) / 2;
-			
-			fAlpha *= _alpha_prompt (myData.iPromptAnimationCount, s_iNbPromptAnimationSteps);
-			
-			if (fAlpha != 0)
-			{
-				glPushMatrix ();
-				if (! pMainDock->container.bIsHorizontal)
-					glRotatef (pMainDock->container.bDirectionUp ? 90. : -90., 0., 0., 1.);
-				glTranslatef (pMainDock->container.iWidth/2, pMainDock->container.iHeight/2, 0.);
-				
-				_cairo_dock_enable_texture ();
-				_cairo_dock_set_blend_alpha ();
-				
-				_cairo_dock_apply_texture_at_size_with_alpha (myData.iArrowTexture, fFrameWidth, fFrameHeight, fAlpha);
-				
-				_cairo_dock_disable_texture ();
-				
 				glPopMatrix();
 			}
 		}
@@ -360,7 +313,8 @@ void cd_do_render_opengl (CairoDock *pMainDock)
 			glPushMatrix ();
 			if (! pMainDock->container.bIsHorizontal)
 				glRotatef (pMainDock->container.bDirectionUp ? 90. : -90., 0., 0., 1.);
-			cairo_dock_draw_rounded_rectangle_opengl (fRadius, fLineWidth, fFrameWidth, fFrameHeight, fDockOffsetX, fDockOffsetY, fFrameColor);
+			glTranslatef (fDockOffsetX, fDockOffsetY, 0.);
+			cairo_dock_draw_rounded_rectangle_opengl (fFrameWidth, fFrameHeight, fRadius, fLineWidth, fFrameColor);
 			glPopMatrix ();
 			
 			// on les dessine.
@@ -431,7 +385,12 @@ void cd_do_render_opengl (CairoDock *pMainDock)
 					_cairo_dock_disable_texture ();
 					fLineWidth = 4.;
 					double fFrameColor[4] = {myConfig.pFrameColor[0]+.1, myConfig.pFrameColor[1]+.1, myConfig.pFrameColor[2]+.1, 1.};
-					cairo_dock_draw_rounded_rectangle_opengl (fRadius, fLineWidth, iWidth * fZoom * fIconScale - fLineWidth, iHeight * fZoom * fIconScale - fLineWidth, -iWidth/2 * fZoom * fIconScale + fLineWidth/2, iHeight * fZoom/2 * fIconScale - fLineWidth/2, fFrameColor);
+					glTranslatef (iWidth/2 * fZoom * fIconScale + fLineWidth/2, iHeight * fZoom/2 * fIconScale - fLineWidth/2, 0.);
+					cairo_dock_draw_rounded_rectangle_opengl (iWidth * fZoom * fIconScale - fLineWidth,
+						iHeight * fZoom * fIconScale - fLineWidth,
+						fRadius,
+						fLineWidth,
+						fFrameColor);
 					_cairo_dock_enable_texture ();
 					_cairo_dock_set_blend_alpha ();
 				}
@@ -447,7 +406,7 @@ void cd_do_render_opengl (CairoDock *pMainDock)
 		double fFrameWidth = myData.iTextWidth;
 		double fTextScale = (fFrameWidth > pMainDock->container.iWidth ? (double) pMainDock->container.iWidth / fFrameWidth : 1.);
 		double fFrameHeight = myData.iTextHeight;
-		double fRadius = myBackground.iDockRadius * myConfig.fFontSizeRatio;
+		double fRadius = myDocksParam.iDockRadius * myConfig.fFontSizeRatio;
 		double fLineWidth = 0.;
 		
 		double fDockOffsetX, fDockOffsetY;  // Offset du coin haut gauche du cadre.
@@ -459,7 +418,8 @@ void cd_do_render_opengl (CairoDock *pMainDock)
 		
 		if (! pMainDock->container.bIsHorizontal)
 			glRotatef (pMainDock->container.bDirectionUp ? 90. : -90., 0., 0., 1.);
-		cairo_dock_draw_rounded_rectangle_opengl (fRadius, 0, fFrameWidth, fFrameHeight, fDockOffsetX, fDockOffsetY, fFrameColor);
+		glTranslatef (fDockOffsetX, fDockOffsetY, 0.);
+		cairo_dock_draw_rounded_rectangle_opengl (fFrameWidth, fFrameHeight, fRadius, 0, fFrameColor);
 		glPopMatrix();
 		
 		// dessin des lettres.
@@ -467,14 +427,13 @@ void cd_do_render_opengl (CairoDock *pMainDock)
 		_cairo_dock_set_blend_alpha ();
 		_cairo_dock_set_alpha (fAlpha);
 		
+		cairo_dock_set_perspective_view (CAIRO_CONTAINER (pMainDock));
 		if (pMainDock->container.bIsHorizontal)
 		{
-			cairo_dock_set_perspective_view (pMainDock->container.iWidth, pMainDock->container.iHeight);
 			glTranslatef (-pMainDock->container.iWidth/2, -pMainDock->container.iHeight/2, 0.);
 		}
 		else
 		{
-			cairo_dock_set_perspective_view (pMainDock->container.iHeight, pMainDock->container.iWidth);
 			glTranslatef (-pMainDock->container.iHeight/2, -pMainDock->container.iWidth/2, 0.);
 		}
 		glEnable (GL_DEPTH_TEST);
@@ -558,14 +517,13 @@ void cd_do_render_opengl (CairoDock *pMainDock)
 			
 			glPopMatrix();
 		}
+		cairo_dock_set_ortho_view (CAIRO_CONTAINER (pMainDock));
 		if (pMainDock->container.bIsHorizontal)
 		{
-			cairo_dock_set_ortho_view (pMainDock->container.iWidth, pMainDock->container.iHeight);
 			glTranslatef (-pMainDock->container.iWidth/2, -pMainDock->container.iHeight/2, 0.);
 		}
 		else
 		{
-			cairo_dock_set_ortho_view (pMainDock->container.iHeight, pMainDock->container.iWidth);
 			glTranslatef (-pMainDock->container.iHeight/2, -pMainDock->container.iWidth/2, 0.);
 		}
 		glDisable (GL_DEPTH_TEST);
