@@ -49,8 +49,8 @@ Voila pour la petite explication :-)
 #include <cairo-glitz.h>
 #endif
 
-#include <rendering-commons.h>
-#include <rendering-parabole.h>
+#include "rendering-commons.h"
+#include "rendering-parabole.h"
 
 extern double my_fParaboleCurvature;  // puissance de x (alpha).
 extern double my_fParaboleRatio;  // ratio hauteur / largeur fixe => coef de la parabole (lambda).
@@ -72,16 +72,22 @@ static double *s_pReferenceParaboleT = NULL;
 #define PARABOLE_DISTANCE_OUT2 4900
 #define PARABOLE_DISTANCE_EDGE2 2500
 
-void cd_rendering_set_subdock_position_parabole (Icon *pPointedIcon, CairoDock *pDock)
+static void cd_rendering_set_subdock_position_parabole (Icon *pPointedIcon, CairoDock *pDock)
 {
 	CairoDock *pSubDock = pPointedIcon->pSubDock;
 	int iMouseX = pDock->container.iMouseX;
 	//int iX = iMouseX + (-iMouseX + pPointedIcon->fDrawX + pPointedIcon->fWidth * pPointedIcon->fScale / 2) / 2;
 	int iX = iMouseX;
 	
-	if ((pDock->container.iWindowPositionX - (pDock->container.bIsHorizontal ? pDock->iScreenOffsetX : pDock->iScreenOffsetY) + pPointedIcon->fDrawX < g_iScreenWidth[pDock->container.bIsHorizontal] / 2) ^ my_bParaboleCurveOutside)
+	if ((pDock->container.iWindowPositionX - (pDock->container.bIsHorizontal ? pDock->iScreenOffsetX : pDock->iScreenOffsetY) + pPointedIcon->fDrawX < g_desktopGeometry.iScreenWidth[pDock->container.bIsHorizontal] / 2) ^ my_bParaboleCurveOutside)
 	{
-		iX = iMouseX + MIN (0, -iMouseX + pPointedIcon->fDrawX + pPointedIcon->fWidth * pPointedIcon->fScale / 2);
+		///iX = iMouseX + MIN (0, -iMouseX + pPointedIcon->fDrawX + pPointedIcon->fWidth * pPointedIcon->fScale / 2);
+		iX = pPointedIcon->fDrawX;
+		if (pSubDock->icons != NULL)
+		{
+			Icon *icon = pSubDock->icons->data;
+			iX += (pPointedIcon->fWidth * pPointedIcon->fScale - icon->fWidth) / 2;
+		}
 		//cd_debug ("recalage : %.2f (%d)\n", -iMouseX + pPointedIcon->fDrawX + pPointedIcon->fWidth * pPointedIcon->fScale / 2, pSubDock->iMaxLabelWidth);
 		pSubDock->fAlign = 0;
 		pSubDock->iGapY = (pDock->iGapY + pDock->iMaxDockHeight);
@@ -89,10 +95,17 @@ void cd_rendering_set_subdock_position_parabole (Icon *pPointedIcon, CairoDock *
 	}
 	else
 	{
-		iX = iMouseX + MAX (0, -iMouseX + pPointedIcon->fDrawX + pPointedIcon->fWidth * pPointedIcon->fScale / 2);
+		///iX = iMouseX + MAX (0, -iMouseX + pPointedIcon->fDrawX + pPointedIcon->fWidth * pPointedIcon->fScale / 2);
+		iX = pPointedIcon->fDrawX;
+		if (pSubDock->icons != NULL)
+		{
+			Icon *icon = pSubDock->icons->data;
+			iX += icon->fWidth + (pPointedIcon->fWidth * pPointedIcon->fScale - icon->fWidth) / 2;
+		}
 		pSubDock->fAlign = 1;
 		pSubDock->iGapY = (pDock->iGapY + pDock->iMaxDockHeight);
-		pSubDock->iGapX =  pDock->container.iWindowPositionX - (pDock->container.bIsHorizontal ? pDock->iScreenOffsetX : pDock->iScreenOffsetY) + iX - g_iScreenWidth[pDock->container.bIsHorizontal] + pSubDock->iMaxLabelWidth;
+		pSubDock->iGapX =  pDock->container.iWindowPositionX - (pDock->container.bIsHorizontal ? pDock->iScreenOffsetX : pDock->iScreenOffsetY) + iX - g_desktopGeometry.iScreenWidth[pDock->container.bIsHorizontal] + pSubDock->iMaxLabelWidth;
+		
 	}
 	//cd_debug ("pSubDock->iGapY : %d\n", pSubDock->iGapY);
 }
@@ -176,7 +189,7 @@ static void cd_rendering_calculate_next_point (double xn, double yn, double ds,
 }
 
 
-void cd_rendering_calculate_reference_parabole (double alpha)
+static void cd_rendering_calculate_reference_parabole (double alpha)
 {
 	if (s_pReferenceParaboleS == NULL)
 	{
@@ -202,7 +215,7 @@ void cd_rendering_calculate_reference_parabole (double alpha)
 		s_pReferenceParaboleT[0] = 0;
 	}
 	
-	double w = g_iScreenHeight[CAIRO_DOCK_HORIZONTAL] / my_fParaboleRatio;
+	double w = g_desktopGeometry.iScreenHeight[CAIRO_DOCK_HORIZONTAL] / my_fParaboleRatio;
 	double lambda = my_fParaboleRatio * pow (w, 1 - alpha);
 	double s=0, ds = 1;
 	double x = 0, y = 0, theta = 0;
@@ -229,7 +242,7 @@ void cd_rendering_calculate_reference_parabole (double alpha)
 
 double cd_rendering_interpol_curvilign_abscisse (double x, double y, double lambda, double alpha)
 {
-	double w = g_iScreenHeight[CAIRO_DOCK_HORIZONTAL] / my_fParaboleRatio;  // aie, au changement de resolution ...
+	double w = g_desktopGeometry.iScreenHeight[CAIRO_DOCK_HORIZONTAL] / my_fParaboleRatio;  // aie, au changement de resolution ...
 	double lambda_reference = my_fParaboleRatio * pow (w, 1 - alpha);
 	//cd_debug ("%s (%.2f / %.2f)\n", __func__, lambda, lambda_reference);
 	if (my_fParaboleRatio < 1)
@@ -247,7 +260,7 @@ double cd_rendering_interpol_curvilign_abscisse (double x, double y, double lamb
 }
 
 
-void cd_rendering_calculate_max_dock_size_parabole (CairoDock *pDock)
+static void cd_rendering_calculate_max_dock_size_parabole (CairoDock *pDock)
 {
 	static double fParaboleCurvature= 0;
 	if (s_pReferenceParaboleS == NULL || my_fParaboleCurvature != fParaboleCurvature)
@@ -297,8 +310,8 @@ void cd_rendering_calculate_max_dock_size_parabole (CairoDock *pDock)
 		//cd_debug ("=> %.2fx%.2f , %.2f", w, h, lambda);
 	}
 	
-	pDock->iMaxDockHeight = h + pDock->iMaxIconHeight * sqrt (5./4.) * (1 + my_fParaboleMagnitude * g_fAmplitude);
-	pDock->iMaxDockWidth = w + pDock->iMaxIconHeight * (.5+sqrt(5./4.)) * (1 + my_fParaboleMagnitude * g_fAmplitude);  // ce serait plutot MaxIconWidth mais bon ...
+	pDock->iMaxDockHeight = h + pDock->iMaxIconHeight * sqrt (5./4.) * (1 + my_fParaboleMagnitude * myIconsParam.fAmplitude);
+	pDock->iMaxDockWidth = w + pDock->iMaxIconHeight * (.5+sqrt(5./4.)) * (1 + my_fParaboleMagnitude * myIconsParam.fAmplitude);  // ce serait plutot MaxIconWidth mais bon ...
 	
 	pDock->iMaxDockWidth += pDock->iMaxLabelWidth;  // theta(0) = 0 => texte horizontal.
 	double fOrientationMax = G_PI/2 - atan (my_fParaboleRatio * my_fParaboleCurvature);  // fCurve_ (W) se simplifie ici.
@@ -313,7 +326,7 @@ void cd_rendering_calculate_max_dock_size_parabole (CairoDock *pDock)
 }
 
 
-void cd_rendering_render_parabole (cairo_t *pCairoContext, CairoDock *pDock)
+static void cd_rendering_render_parabole (cairo_t *pCairoContext, CairoDock *pDock)
 {
 	//g_print ("pDock->fFoldingFactor : %.2f\n", pDock->fFoldingFactor);
 	
@@ -324,8 +337,8 @@ void cd_rendering_render_parabole (cairo_t *pCairoContext, CairoDock *pDock)
 	//\____________________ On dessine le cadre.
 	
 	//\____________________ On dessine la ficelle qui les joint.
-	if (myIcons.iStringLineWidth > 0)
-		cairo_dock_draw_string (pCairoContext, pDock, myIcons.iStringLineWidth, FALSE, FALSE);
+	if (myIconsParam.iStringLineWidth > 0)
+		cairo_dock_draw_string (pCairoContext, pDock, myIconsParam.iStringLineWidth, FALSE, FALSE);
 	
 	
 	//\____________________ On dessine les icones et leurs etiquettes, mais separement.
@@ -532,7 +545,7 @@ Icon *cd_rendering_calculate_icons_parabole (CairoDock *pDock)
 		return NULL;
 	
 	//\____________________ On calcule la projection du curseur sur la courbe.
-	double fMaxScale =  1. + my_fParaboleMagnitude * g_fAmplitude;
+	double fMaxScale =  1. + my_fParaboleMagnitude * myIconsParam.fAmplitude;
 	double w = MAX (1, pDock->container.iWidth - pDock->iMaxLabelWidth - pDock->iMaxIconHeight * (.5+sqrt(5./4.)) * fMaxScale);
 	double h = my_fParaboleRatio * w;
 	double alpha = my_fParaboleCurvature, lambda = h / pow (w, alpha);
@@ -631,7 +644,7 @@ Icon *cd_rendering_calculate_icons_parabole (CairoDock *pDock)
 	} while (ic != pFirstDrawnElement);
 	
 	//cd_debug ("  derniere icone : %.2f (s:%.2f)", icon->fX + icon->fHeight * icon->fScale - pFirstIcon->fX, fCurvilignAbscisse);
-	if (! pDock->container.bInside || fCurvilignAbscisse > icon->fX + icon->fHeight * icon->fScale - pFirstIcon->fX - (pDock->fFoldingFactor > 0 ? 20 : 0) || fCurvilignAbscisse <= 0)
+	if (! pDock->container.bInside || fCurvilignAbscisse > icon->fX + icon->fHeight * icon->fScale - pFirstIcon->fX - (pDock->fFoldingFactor > 0 ? 20 : -30) || fCurvilignAbscisse <= 0)  // on laisse 30 pixels de rab pour ne pas etre trop sensible a l'extremite du dock.
 	{
 		//cd_debug ("<<< on sort de la parabole >>>");
 		pDock->iMousePositionType = CAIRO_DOCK_MOUSE_OUTSIDE;
@@ -658,24 +671,7 @@ Icon *cd_rendering_calculate_icons_parabole (CairoDock *pDock)
 }
 
 
-void cd_rendering_register_parabole_renderer (const gchar *cRendererName)
-{
-	CairoDockRenderer *pRenderer = g_new0 (CairoDockRenderer, 1);
-	pRenderer->cReadmeFilePath = g_strdup_printf ("%s/readme-parabolic-view", MY_APPLET_SHARE_DATA_DIR);
-	pRenderer->cPreviewFilePath = g_strdup_printf ("%s/preview-parabolic.jpg", MY_APPLET_SHARE_DATA_DIR);
-	pRenderer->compute_size = cd_rendering_calculate_max_dock_size_parabole;
-	pRenderer->calculate_icons = cd_rendering_calculate_icons_parabole;
-	pRenderer->render = cd_rendering_render_parabole;
-	pRenderer->render_optimized = NULL;
-	pRenderer->render_opengl = cd_rendering_render_parabole_opengl;
-	pRenderer->set_subdock_position = cd_rendering_set_subdock_position_parabole;
-	pRenderer->cDisplayedName = D_ (cRendererName);
-	
-	cairo_dock_register_renderer (cRendererName, pRenderer);
-}
-
-
-void cd_rendering_render_parabole_opengl (CairoDock *pDock)
+static void cd_rendering_render_parabole_opengl (CairoDock *pDock)
 {
 	//g_print ("pDock->fFoldingFactor : %.2f\n", pDock->fFoldingFactor);
 	
@@ -686,8 +682,8 @@ void cd_rendering_render_parabole_opengl (CairoDock *pDock)
 	//\____________________ On dessine le cadre.
 	
 	//\____________________ On dessine la ficelle qui les joint.
-	if (myIcons.iStringLineWidth > 0)
-		cairo_dock_draw_string_opengl (pDock, myIcons.iStringLineWidth, FALSE, FALSE);
+	if (myIconsParam.iStringLineWidth > 0)
+		cairo_dock_draw_string_opengl (pDock, myIconsParam.iStringLineWidth, FALSE, FALSE);
 	
 	//\____________________ On dessine les icones et leurs etiquettes, mais separement.
 	GList *pFirstDrawnElement = (pDock->pFirstDrawnElement != NULL ? pDock->pFirstDrawnElement : pDock->icons);
@@ -705,7 +701,7 @@ void cd_rendering_render_parabole_opengl (CairoDock *pDock)
 		
 		cairo_dock_render_one_icon_opengl (icon, pDock, fDockMagnitude, FALSE);
 		
-		if (icon->pTextBuffer != NULL)  // en opengl on dessine les etiquettes meme pendant le depliage.
+		if (icon->iLabelTexture != 0)  // en opengl on dessine les etiquettes meme pendant le depliage.
 		{
 			glPushMatrix ();
 			cairo_dock_translate_on_icon_opengl (icon, CAIRO_CONTAINER (pDock), 1.);
@@ -715,7 +711,8 @@ void cd_rendering_render_parabole_opengl (CairoDock *pDock)
 			glTranslatef (icon->fWidth * icon->fScale/2, -icon->fHeight * icon->fScale/2, 0.);
 			
 			_cairo_dock_enable_texture ();
-			_cairo_dock_set_blend_over ();
+			///_cairo_dock_set_blend_over ();
+			_cairo_dock_set_blend_alpha ();
 			_cairo_dock_set_alpha ((1 - pDock->fFoldingFactor) * (1 - pDock->fFoldingFactor));
 			
 			if (pDock->fAlign == 1)
@@ -762,3 +759,22 @@ void cd_rendering_render_parabole_opengl (CairoDock *pDock)
 	} while (ic != pFirstDrawnElement);
 	glPopMatrix ();
 }
+
+
+void cd_rendering_register_parabole_renderer (const gchar *cRendererName)
+{
+	CairoDockRenderer *pRenderer = g_new0 (CairoDockRenderer, 1);
+	// interface
+	pRenderer->compute_size = cd_rendering_calculate_max_dock_size_parabole;
+	pRenderer->calculate_icons = cd_rendering_calculate_icons_parabole;
+	pRenderer->render = cd_rendering_render_parabole;
+	pRenderer->render_optimized = NULL;
+	pRenderer->render_opengl = cd_rendering_render_parabole_opengl;
+	pRenderer->set_subdock_position = cd_rendering_set_subdock_position_parabole;
+	// parametres
+	pRenderer->cDisplayedName = D_ (cRendererName);
+	pRenderer->cReadmeFilePath = g_strdup (MY_APPLET_SHARE_DATA_DIR"/readme-parabolic-view");
+	pRenderer->cPreviewFilePath = g_strdup (MY_APPLET_SHARE_DATA_DIR"/preview-parabolic.jpg");
+	
+	cairo_dock_register_renderer (cRendererName, pRenderer);
+}
