@@ -27,17 +27,19 @@
 CD_APPLET_GET_CONFIG_BEGIN
 	myConfig.cUserAction = CD_CONFIG_GET_STRING ("Configuration", "user action");
 	myConfig.cUserAction2 = CD_CONFIG_GET_STRING ("Configuration", "user action2");
-	myConfig.bInvertButtons = CD_CONFIG_GET_BOOLEAN ("Configuration", "invert");
+	myConfig.iActionOnClick = CD_CONFIG_GET_INTEGER_WITH_DEFAULT ("Configuration", "click", 1);
+	myConfig.iActionOnMiddleClick = CD_CONFIG_GET_INTEGER_WITH_DEFAULT ("Configuration", "middle-click", 0);
 	myConfig.iShutdownTime = CD_CONFIG_GET_INTEGER ("Configuration", "shutdown time");
+	myConfig.cDefaultLabel = CD_CONFIG_GET_STRING ("Icon", "name");
 CD_APPLET_GET_CONFIG_END
 
 
 CD_APPLET_RESET_CONFIG_BEGIN
 	g_free (myConfig.cUserAction);
+	g_free (myConfig.cDefaultLabel);
 CD_APPLET_RESET_CONFIG_END
 
 
 CD_APPLET_RESET_DATA_BEGIN
 	
 CD_APPLET_RESET_DATA_END
-
