@@ -163,7 +163,7 @@
 /////////////////////////////////
 // Les Fonctions propres a MP. //
 /////////////////////////////////
-static inline void _extract_playing_status_mpris (int iStatus)
+static inline void _set_playing_status_mpris (int iStatus)
 {
 	switch (iStatus)
 	{
@@ -219,7 +219,7 @@ void cd_mpris_getPlaying (void)
 {
 	cd_debug ("%s ()\n", __func__);
 	int iStatus = _mpris_get_status (0);
-	_extract_playing_status_mpris (iStatus);
+	_set_playing_status_mpris (iStatus);
 }
 
 /* Teste si MP joue en boucle ou non
@@ -246,16 +246,37 @@ gboolean cd_mpris_is_shuffle (void)
  */
 void cd_mpris_get_time_elapsed (void)
 {
-	myData.iCurrentTime = cairo_dock_dbus_get_integer (myData.dbus_proxy_player, "PositionGet") / 1000;
-	//cd_debug ("myData.iCurrentTime <- %d\n", myData.iCurrentTime);
+	myData.iCurrentTime = cairo_dock_dbus_get_integer (myData.dbus_proxy_player, "PositionGet");
+	if (myData.iCurrentTime > 0)  // -1 signifie que la valeur n'a pas pu etre retrouvee (lecteur ferme).
+		myData.iCurrentTime /= 1000;
 }
 
-/* Renvoie le temps ecoule en secondes..
+/* Renvoie le numero de la chanson courante dans la playlist.
  */
+static void _on_get_current_track (DBusGProxy *proxy, DBusGProxyCall *call_id, gpointer data)
+{
+	gboolean bSuccess = dbus_g_proxy_end_call (proxy,
+		call_id,
+		NULL,
+		G_TYPE_INT,
+		&myData.iTrackListIndex,
+		G_TYPE_INVALID);
+	//g_print ("myData.iTrackListIndex <- %d\n", myData.iTrackListIndex);
+	if (myConfig.iQuickInfoType == MY_APPLET_TRACK && myData.iTrackListIndex > 0)
+	{
+		CD_APPLET_SET_QUICK_INFO_ON_MY_ICON_PRINTF ("%s%d", (myDesklet && myDesklet->container.iWidth >= 64 ? D_("Track") : ""), myData.iTrackListIndex);
+		CD_APPLET_REDRAW_MY_ICON;
+	}
+}
 void cd_mpris_get_track_index (void)
 {
-	myData.iTrackListIndex = cairo_dock_dbus_get_integer (myData.dbus_proxy_shell, "GetCurrentTrack");
-	//cd_debug ("myData.iTrackListIndex <- %d\n", myData.iTrackListIndex);
+	DBusGProxyCall* pCall= dbus_g_proxy_begin_call (myData.dbus_proxy_shell, "GetCurrentTrack",
+		(DBusGProxyCallNotify)_on_get_current_track,
+		NULL,
+		(GDestroyNotify) NULL,
+		G_TYPE_INVALID);
+	/**myData.iTrackListIndex = cairo_dock_dbus_get_integer (myData.dbus_proxy_shell, "GetCurrentTrack");
+	g_print ("myData.iTrackListIndex <- %d\n", myData.iTrackListIndex);*/
 }
 
 static inline int _get_integer_value (GValue *value)
@@ -326,9 +347,19 @@ static inline void _extract_metadata (GHashTable *data_list)
 	
 	value = (GValue *) g_hash_table_lookup(data_list, "tracknumber");
 	if (value == NULL)
-		value = (GValue *) g_hash_table_lookup(data_list, "track-number");
-	if (value != NULL && G_VALUE_HOLDS_INT(value))
-		myData.iTrackNumber = g_value_get_int(value);
+		value = (GValue *) g_hash_table_lookup(data_list, "track-number");  // au cas ou
+	if (value != NULL)
+	{
+		if (G_VALUE_HOLDS_INT (value))  // amarok
+			myData.iTrackNumber = g_value_get_int (value);
+		else if (G_VALUE_HOLDS_UINT (value))
+			myData.iTrackNumber = g_value_get_uint (value);
+		else if (G_VALUE_HOLDS_STRING (value))  // qmmp
+		{
+			const gchar *s = g_value_get_string (value);
+			myData.iTrackNumber = (s ? atoi(s) : 0);
+		}
+	}
 	else
 		myData.iTrackNumber = 0;
 	cd_message ("  iTrackNumber <- %d", myData.iTrackNumber);
@@ -359,7 +390,7 @@ static inline void _extract_metadata (GHashTable *data_list)
 	else myData.cPlayingUri = NULL;
 	cd_message ("  cUri <- %s", myData.cPlayingUri);
 	
-	gchar *cCoverPath = NULL;
+	const gchar *cCoverPath = NULL;
 	value = (GValue *) g_hash_table_lookup(data_list, "arturl");
 	if (value != NULL && G_VALUE_HOLDS_STRING(value))
 	{
@@ -409,9 +440,9 @@ void cd_mpris_getSongInfos ()
 // Les callbacks des signaux DBus. //
 /////////////////////////////////////
 
-/* Fonction executée à chaque changement de musique.
+/* Fonction executee a chaque changement de musique.
  */
-void onChangeSong(DBusGProxy *player_proxy, GHashTable *metadata, gpointer data)
+void onChangeSong_mpris(DBusGProxy *player_proxy, GHashTable *metadata, gpointer data)
 {
 	CD_APPLET_ENTER;
 	cd_debug ("MP : %s ()\n", __func__);
@@ -420,6 +451,7 @@ void onChangeSong(DBusGProxy *player_proxy, GHashTable *metadata, gpointer data)
 	{
 		_extract_metadata (metadata);
 		myData.bIsRunning = TRUE;
+		myData.iPlayingStatus = PLAYER_PLAYING;  // pour les lecteurs bugues comem Exaile qui envoit un statut "stop" au changement de musique sans envoyer de status "play" par la suite. On considere donc que si le lecteur joue une nouvelle musique, c'est qu'il est en "play".
 	}
 	else
 	{
@@ -449,11 +481,12 @@ void onChangeSong(DBusGProxy *player_proxy, GHashTable *metadata, gpointer data)
 void onChangePlaying_mpris (DBusGProxy *player_proxy, GValueArray *status, gpointer data)
 {
 	CD_APPLET_ENTER;
-	cd_debug ("MP : %s (%x)\n", __func__, status);
+	//cd_debug ("MP : %s (%x)\n", __func__, status);
 	myData.bIsRunning = TRUE;
+	myData.iGetTimeFailed = 0;
 	int iStatus = _extract_status_mpris (status, 0);
-	_extract_playing_status_mpris (iStatus);
-	cd_debug ("-> myData.iPlayingStatus : %d\n", myData.iPlayingStatus);
+	_set_playing_status_mpris (iStatus);
+	cd_debug ("myData.iPlayingStatus <- %d", myData.iPlayingStatus);
 	
 	if (myData.iPlayingStatus == PLAYER_PLAYING)  // le handler est stoppe lorsque le lecteur ne joue rien.
 		cd_musicplayer_relaunch_handler ();
@@ -471,10 +504,10 @@ void onChangePlaying_mpris (DBusGProxy *player_proxy, GValueArray *status, gpoin
 
 /* Fonction executée à chaque changement dans la TrackList.
  */
-void onChangeTrackList (DBusGProxy *player_proxy, gint iNewTrackListLength, gpointer data)
+void onChangeTrackList_mpris (DBusGProxy *player_proxy, gint iNewTrackListLength, gpointer data)
 {
 	CD_APPLET_ENTER;
-	cd_debug ("MP : %s (%d)\n", __func__, iNewTrackListLength);
+	cd_debug ("MP : %s (%d)", __func__, iNewTrackListLength);
 	myData.iTrackListLength = iNewTrackListLength;
 	cd_mpris_get_track_index ();
 	CD_APPLET_LEAVE ();
@@ -488,7 +521,7 @@ void onChangeTrackList (DBusGProxy *player_proxy, gint iNewTrackListLength, gpoi
  */
 gboolean cd_mpris_dbus_connect_to_bus (void)
 {
-	if (cairo_dock_bdus_is_enabled ())
+	if (cairo_dock_dbus_is_enabled ())
 	{
 		// cree les proxys.
 		myData.dbus_enable = cd_musicplayer_dbus_connect_to_bus ();
@@ -505,13 +538,13 @@ gboolean cd_mpris_dbus_connect_to_bus (void)
 			MP_DBUS_TYPE_SONG_METADATA,
 			G_TYPE_INVALID);
 		dbus_g_proxy_connect_signal(myData.dbus_proxy_player, "TrackChange",
-			G_CALLBACK(onChangeSong), NULL, NULL);
+			G_CALLBACK(onChangeSong_mpris), NULL, NULL);
 		
 		dbus_g_proxy_add_signal(myData.dbus_proxy_shell, "TrackListChange",
 			MP_DBUS_TYPE_TRACKLIST_DATA,
 			G_TYPE_INVALID);
 		dbus_g_proxy_connect_signal(myData.dbus_proxy_shell, "TrackListChange",
-			G_CALLBACK(onChangeTrackList), NULL, NULL);
+			G_CALLBACK(onChangeTrackList_mpris), NULL, NULL);
 		
 		return TRUE;
 	}
@@ -528,10 +561,10 @@ void cd_mpris_free_data (void)
 			G_CALLBACK(onChangePlaying_mpris), NULL);
 		
 		dbus_g_proxy_disconnect_signal(myData.dbus_proxy_player, "TrackChange",
-			G_CALLBACK(onChangeSong), NULL);
+			G_CALLBACK(onChangeSong_mpris), NULL);
 		
 		dbus_g_proxy_disconnect_signal(myData.dbus_proxy_shell, "TrackListChange",
-			G_CALLBACK(onChangeTrackList), NULL);
+			G_CALLBACK(onChangeTrackList_mpris), NULL);
 	}
 	
 	musicplayer_dbus_disconnect_from_bus();
@@ -613,22 +646,53 @@ void cd_mpris_read_data (void)
 			if (myData.iPlayingStatus == PLAYER_PLAYING)
 			{
 				cd_mpris_get_time_elapsed ();
-				if (myData.iCurrentTime < 0)
-					myData.iPlayingStatus = PLAYER_STOPPED;
+				if (myData.iCurrentTime < 0)  // aucune info de temps sur le bus => lecteur ferme.
+				{
+					myData.iGetTimeFailed ++;  // certains lecteurs (qmmp par exemple) envoient le signal 'playing' trop tot lorsqu'on les relance, ils ne fournissent pas de duree tout de suite, et donc l'applet stoppe. On fait donc 3 tentatives avant de declarer le lecteur ferme.
+					cd_debug ("failed to get time %d time(s)", myData.iGetTimeFailed);
+					if (myData.iGetTimeFailed > 2)
+					{
+						cd_debug (" => player is likely closed");
+						myData.iPlayingStatus = PLAYER_NONE;
+						myData.iCurrentTime = -2;  // le temps etait a -1, on le change pour provoquer un redraw.
+						myData.bIsRunning = FALSE;
+					}
+				}
+				else
+					myData.iGetTimeFailed = 0;
 			}
 			else if (myData.iPlayingStatus != PLAYER_PAUSED)  // en pause le temps reste constant.
+			{
 				myData.iCurrentTime = 0;
+				myData.iGetTimeFailed = 0;
+			}
 		}
 		else 
 		{
 			myData.iCurrentTime = 0;
+			myData.iGetTimeFailed = 0;
 		}
-		cd_message (" myData.iCurrentTime <- %d", __func__, myData.iCurrentTime);
+		//cd_message (" myData.iCurrentTime <- %d", __func__, myData.iCurrentTime);
 	}
 }
 
 /* Initialise le backend de MP.
  */
+static void _on_detect_player (void)
+{
+	if (myApplet == NULL)  // precaution.
+		return ;
+	cd_debug ("myData.bIsRunning : %d\n", myData.bIsRunning);
+	if(myData.bIsRunning)  // player en cours d'execution, on recupere son etat.
+	{
+		cd_debug ("MP : MP is running\n");
+		cd_mpris_getPlaying ();
+		cd_mpris_getSongInfos ();
+		cd_musicplayer_update_icon (TRUE);
+		cd_musicplayer_relaunch_handler ();
+	}
+}
+
 void cd_mpris_configure (void)
 {
 	myData.DBus_commands.path = "/Player";
@@ -636,21 +700,11 @@ void cd_mpris_configure (void)
 	myData.DBus_commands.interface = "org.freedesktop.MediaPlayer";
 	myData.DBus_commands.interface2 = "org.freedesktop.MediaPlayer";
 	
-	myData.dbus_enable = cd_mpris_dbus_connect_to_bus ();  // se connecte au bus et aux signaux de MP.
+	myData.dbus_enable = cd_mpris_dbus_connect_to_bus ();  // se connecte au bus et aux signaux du lecteur.
 	if (myData.dbus_enable)
 	{
-		cd_musicplayer_dbus_detect_player ();  // on teste la presence de MP sur le bus <=> s'il est ouvert ou pas.
-		if(myData.bIsRunning)  // player en cours d'execution, on recupere son etat.
-		{
-			cd_debug ("MP : MP is running\n");
-			cd_mpris_getPlaying ();
-			cd_mpris_getSongInfos ();
-			cd_musicplayer_update_icon (TRUE);
-		}
-		else  // player eteint.
-		{
-			cd_musicplayer_set_surface (PLAYER_NONE);
-		}
+		cd_musicplayer_dbus_detect_player_async (_on_detect_player);  // on teste la presence du lecteur sur le bus <=> s'il est ouvert ou pas.
+		cd_musicplayer_set_surface (PLAYER_NONE);  // en attendant de le savoir, on considere qu'il est eteint.
 	}
 	else  // sinon on signale par l'icone appropriee que le bus n'est pas accessible.
 	{
