@@ -26,40 +26,46 @@
 #include "applet-desktops.h"
 #include "applet-draw.h"
 
-gboolean my_bRotateIconsOnEllipse = TRUE;
-
-
-static void _cd_switcher_draw_windows_on_viewport (Icon *pIcon, gint *data)
+typedef struct {
+	gint iNumDesktop;
+	gint iNumViewportX;
+	gint iNumViewportY;
+	gint iOneViewportWidth;
+	gint iOneViewportHeight;
+	cairo_t *pCairoContext;
+	} CDSwitcherDesktop;
+ 
+static void _cd_switcher_draw_windows_on_viewport (Icon *pIcon, CDSwitcherDesktop *data)
 {
 	if (pIcon == NULL || pIcon->fInsertRemoveFactor > 0)
 		return ;
 	if (pIcon->bIsHidden && ! myConfig.bDisplayHiddenWindows)
 		return ;
-	int iNumDesktop = data[0];
-	int iNumViewportX = data[1];
-	int iNumViewportY = data[2];
-	int iOneViewportWidth = data[3];
-	int iOneViewportHeight = data[4];
-	cairo_t *pCairoContext = GINT_TO_POINTER (data[5]);
+	int iNumDesktop = data->iNumDesktop;
+	int iNumViewportX = data->iNumViewportX;
+	int iNumViewportY = data->iNumViewportY;
+	int iOneViewportWidth = data->iOneViewportWidth;
+	int iOneViewportHeight = data->iOneViewportHeight;
+	cairo_t *pCairoContext = data->pCairoContext;
 	
 	// On calcule les coordonnees en repere absolu.
 	int x = pIcon->windowGeometry.x;  // par rapport au viewport courant.
-	x += myData.switcher.iCurrentViewportX * g_iXScreenWidth[CAIRO_DOCK_HORIZONTAL];  // repere absolu
+	x += myData.switcher.iCurrentViewportX * g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL];  // repere absolu
 	if (x < 0)
-		x += g_iNbViewportX * g_iXScreenWidth[CAIRO_DOCK_HORIZONTAL];
+		x += g_desktopGeometry.iNbViewportX * g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL];
 	int y = pIcon->windowGeometry.y;
-	y += myData.switcher.iCurrentViewportY * g_iXScreenHeight[CAIRO_DOCK_HORIZONTAL];
+	y += myData.switcher.iCurrentViewportY * g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL];
 	if (y < 0)
-		y += g_iNbViewportY * g_iXScreenHeight[CAIRO_DOCK_HORIZONTAL];
+		y += g_desktopGeometry.iNbViewportY * g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL];
 	int w = pIcon->windowGeometry.width, h = pIcon->windowGeometry.height;
 	
 	// test d'intersection avec le viewport donne.
 	//g_print (" %s : (%d;%d) %dx%d\n", pIcon->cName, x, y, w, h);
 	if ((pIcon->iNumDesktop != -1 && pIcon->iNumDesktop != iNumDesktop) ||
-		x + w <= iNumViewportX * g_iXScreenWidth[CAIRO_DOCK_HORIZONTAL] ||
-		x >= (iNumViewportX + 1) * g_iXScreenWidth[CAIRO_DOCK_HORIZONTAL] ||
-		y + h <= iNumViewportY * g_iXScreenHeight[CAIRO_DOCK_HORIZONTAL] ||
-		y >= (iNumViewportY + 1) * g_iXScreenHeight[CAIRO_DOCK_HORIZONTAL])
+		x + w <= iNumViewportX * g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL] ||
+		x >= (iNumViewportX + 1) * g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL] ||
+		y + h <= iNumViewportY * g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL] ||
+		y >= (iNumViewportY + 1) * g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL])
 		return ;
 	//g_print (" > on la dessine (%x)\n", pIcon->pIconBuffer);
 	
@@ -68,10 +74,10 @@ static void _cd_switcher_draw_windows_on_viewport (Icon *pIcon, gint *data)
 	
 	cairo_set_source_rgba (pCairoContext, myConfig.RGBWLineColors[0], myConfig.RGBWLineColors[1], myConfig.RGBWLineColors[2], myConfig.RGBWLineColors[3]);
 	cairo_rectangle (pCairoContext,
-		(1.*x/g_iXScreenWidth[CAIRO_DOCK_HORIZONTAL] - iNumViewportX)*iOneViewportWidth,
-		(1.*y/g_iXScreenHeight[CAIRO_DOCK_HORIZONTAL] - iNumViewportY)*iOneViewportHeight,
-		1.*w/g_iXScreenWidth[CAIRO_DOCK_HORIZONTAL]*iOneViewportWidth,
-		1.*h/g_iXScreenHeight[CAIRO_DOCK_HORIZONTAL]*iOneViewportHeight);
+		(1.*x/g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL] - iNumViewportX)*iOneViewportWidth,
+		(1.*y/g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL] - iNumViewportY)*iOneViewportHeight,
+		1.*w/g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL]*iOneViewportWidth,
+		1.*h/g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL]*iOneViewportHeight);
 	if (pIcon->Xid == cairo_dock_get_current_active_window ())
 	{
 		//g_print (" %s est la fenetre active\n", pIcon->cName);
@@ -84,19 +90,15 @@ static void _cd_switcher_draw_windows_on_viewport (Icon *pIcon, gint *data)
 	
 	if (pIcon->pIconBuffer != NULL)
 	{
-		CairoDock *pParentDock = NULL;
-		pParentDock = cairo_dock_search_dock_from_name (pIcon->cParentDockName);
-		if (pParentDock == NULL)
-			pParentDock = g_pMainDock;
 		int iWidth, iHeight;
-		cairo_dock_get_icon_extent (pIcon, CAIRO_CONTAINER (pParentDock), &iWidth, &iHeight);
-		double fZoomX = (double) w/g_iXScreenWidth[CAIRO_DOCK_HORIZONTAL]*iOneViewportWidth / iWidth;
-		double fZoomY = (double) h/g_iXScreenHeight[CAIRO_DOCK_HORIZONTAL]*iOneViewportHeight / iHeight;
+		cairo_dock_get_icon_extent (pIcon, NULL, &iWidth, &iHeight);
+		double fZoomX = (double) w/g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL]*iOneViewportWidth / iWidth;
+		double fZoomY = (double) h/g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL]*iOneViewportHeight / iHeight;
 		double fZoom = MIN (fZoomX, fZoomY);  // on garde le ratio.
 		
 		cairo_translate (pCairoContext,
-			(1.*x/g_iXScreenWidth[CAIRO_DOCK_HORIZONTAL] - iNumViewportX)*iOneViewportWidth + (fZoomX - fZoom) * iWidth/2,
-			(1.*y/g_iXScreenHeight[CAIRO_DOCK_HORIZONTAL] - iNumViewportY)*iOneViewportHeight + (fZoomY - fZoom) * iHeight/2);
+			(1.*x/g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL] - iNumViewportX)*iOneViewportWidth + (fZoomX - fZoom) * iWidth/2,
+			(1.*y/g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL] - iNumViewportY)*iOneViewportHeight + (fZoomY - fZoom) * iHeight/2);
 		cairo_scale (pCairoContext,
 			fZoom,
 			fZoom);
@@ -125,7 +127,8 @@ static int _compare_icons_stack_order (Icon *icon1, Icon *icon2)
 void cd_switcher_draw_main_icon_compact_mode (void)
 {
 	g_return_if_fail (myData.switcher.iNbColumns != 0 && myData.switcher.iNbLines != 0);
-	//cd_debug ("%s (%d;%d)", __func__, myData.switcher.iCurrentLine, myData.switcher.iCurrentColumn);
+	g_return_if_fail (myDrawContext != NULL);
+	//g_print ("%s (%d;%d)\n", __func__, myData.switcher.iCurrentLine, myData.switcher.iCurrentColumn);
 	// On efface l'icone.
 	cairo_dock_erase_cairo_context (myDrawContext);
 	
@@ -141,7 +144,7 @@ void cd_switcher_draw_main_icon_compact_mode (void)
 	double w = iWidth, h = iHeight;
 	if (myConfig.bPreserveScreenRatio)
 	{
-		double r = (double) g_iXScreenWidth[CAIRO_DOCK_HORIZONTAL] / g_iXScreenHeight[CAIRO_DOCK_HORIZONTAL];
+		double r = (double) g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL] / g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL];
 		double r_ = myData.switcher.fOneViewportWidth / myData.switcher.fOneViewportHeight;
 		if (r_ > r)  // on etire trop en largeur.
 		{
@@ -217,10 +220,10 @@ void cd_switcher_draw_main_icon_compact_mode (void)
 	
 	// chaque bureau/viewport.
 	int iNumDesktop=0, iNumViewportX=0, iNumViewportY=0;
-	int k = 0, N = g_iNbDesktops * g_iNbViewportX * g_iNbViewportY;
-	for (j = 0; j < myData.switcher.iNbLines; j ++)
+	int k = 0, N = g_desktopGeometry.iNbDesktops * g_desktopGeometry.iNbViewportX * g_desktopGeometry.iNbViewportY;
+	for (j = 0; j < myData.switcher.iNbLines && k < N; j ++)
 	{
-		for (i = 0; i < myData.switcher.iNbColumns; i ++)
+		for (i = 0; i < myData.switcher.iNbColumns && k < N; i ++)
 		{
 			cairo_save (myDrawContext);
 
@@ -273,26 +276,24 @@ void cd_switcher_draw_main_icon_compact_mode (void)
 				cairo_clip (myDrawContext);
 				
 				//g_print (" dessin des fenetres du bureau (%d;%d;%d) ...\n", iNumDesktop, iNumViewportX, iNumViewportY);
-				gint data[6] = {iNumDesktop, iNumViewportX, iNumViewportY, (int) myData.switcher.fOneViewportWidth, (int) myData.switcher.fOneViewportHeight, GPOINTER_TO_INT (myDrawContext)};
-				g_list_foreach (pWindowList, (GFunc) _cd_switcher_draw_windows_on_viewport, data);
+				CDSwitcherDesktop data = {iNumDesktop, iNumViewportX, iNumViewportY, (int) myData.switcher.fOneViewportWidth, (int) myData.switcher.fOneViewportHeight, myDrawContext};
+				g_list_foreach (pWindowList, (GFunc) _cd_switcher_draw_windows_on_viewport, &data);
 				
 				cairo_restore (myDrawContext);
 			}
 			
 			iNumViewportX ++;
-			if (iNumViewportX == g_iNbViewportX)
+			if (iNumViewportX == g_desktopGeometry.iNbViewportX)
 			{
 				iNumViewportX = 0;
 				iNumViewportY ++;
-				if (iNumViewportY == g_iNbViewportY)
+				if (iNumViewportY == g_desktopGeometry.iNbViewportY)
 				{
 					iNumViewportY = 0;
 					iNumDesktop ++;
 				}
 			}
 			k ++;
-			if (k == N)
-				break ;
 		}
 	}
 	
@@ -379,7 +380,7 @@ void cd_switcher_draw_main_icon_expanded_mode (void)
 		
 		//fMaxScale = (myIcon->pSubDock != NULL ? cairo_dock_get_max_scale (myIcon->pSubDock) : 1);
 		//fRatio = (myIcon->pSubDock != NULL ? myIcon->pSubDock->container.fRatio : 1);
-		gint data[6];
+		CDSwitcherDesktop data;
 		int iNumDesktop=0, iNumViewportX=0, iNumViewportY=0;
 		cairo_t *pCairoContext;
 		Icon *pIcon;
@@ -390,24 +391,23 @@ void cd_switcher_draw_main_icon_expanded_mode (void)
 		{
 			pIcon = ic->data;
 			cairo_dock_get_icon_extent (pIcon, pContainer, &iWidth, &iHeight);
-			
-			data[0] = iNumDesktop;
-			data[1] = iNumViewportX;
-			data[2] = iNumViewportY;
-			data[3] = iWidth;
-			data[4] = iHeight;
 			pCairoContext = cairo_create (pIcon->pIconBuffer);
-			data[5] = GPOINTER_TO_INT (pCairoContext);
 			cairo_set_line_width (pCairoContext, 1.);
 			cairo_set_source_rgba (pCairoContext, myConfig.RGBWLineColors[0], myConfig.RGBWLineColors[1], myConfig.RGBWLineColors[2], myConfig.RGBWLineColors[3]);
-		
-			g_list_foreach (pWindowList, (GFunc) _cd_switcher_draw_windows_on_viewport, data);
+			
+			data.iNumDesktop = iNumDesktop;
+			data.iNumViewportX = iNumViewportX;
+			data.iNumViewportY = iNumViewportY;
+			data.iOneViewportWidth = iWidth;
+			data.iOneViewportHeight = iHeight;
+			data.pCairoContext = pCairoContext;
+			g_list_foreach (pWindowList, (GFunc) _cd_switcher_draw_windows_on_viewport, &data);
 			
 			iNumViewportX ++;
-			if (iNumViewportX == g_iNbViewportX)
+			if (iNumViewportX == g_desktopGeometry.iNbViewportX)
 			{
 				iNumViewportY ++;
-				if (iNumViewportY == g_iNbViewportY)
+				if (iNumViewportY == g_desktopGeometry.iNbViewportY)
 					iNumDesktop ++;
 			}
 			cairo_destroy (pCairoContext);
@@ -436,14 +436,14 @@ void cd_switcher_draw_main_icon (void)
 void cd_switcher_draw_desktops_bounding_box (CairoDesklet *pDesklet)
 {
 	CD_APPLET_ENTER;
-	//g_print ("%s ()\n", __func__);
+	//g_print ("%s (%.2Fx%.2f)\n", __func__, myData.switcher.fOneViewportWidth, myData.switcher.fOneViewportHeight);
 	double x, y, w, h;
 	glTranslatef (-pDesklet->container.iWidth/2, -pDesklet->container.iHeight/2, 0.);
 	
 	w = myData.switcher.fOneViewportWidth/2;
 	h = myData.switcher.fOneViewportHeight/2;
 	int i, j;
-	int k = 0, N = g_iNbDesktops * g_iNbViewportX * g_iNbViewportY;
+	int k = 0, N = g_desktopGeometry.iNbDesktops * g_desktopGeometry.iNbViewportX * g_desktopGeometry.iNbViewportY;
 	
 	for (j = 0; j < myData.switcher.iNbLines; j ++)  // lignes horizontales.
 	{
@@ -519,73 +519,76 @@ static void _cd_switcher_list_window_on_viewport (Icon *pIcon, int iNumDesktop,
 {
 	//g_print (" + %s\n", pIcon->cName);
 	// on recupere la taille de l'icone.
-	CairoDock *pParentDock = cairo_dock_search_dock_from_name (pIcon->cParentDockName);
-	if (pParentDock == NULL)
-		pParentDock = g_pMainDock;
 	int iWidth, iHeight;
-	cairo_dock_get_icon_extent (pIcon, CAIRO_CONTAINER (pParentDock), &iWidth, &iHeight);
+	cairo_dock_get_icon_extent (pIcon, NULL, &iWidth, &iHeight);
 	
 	// on cree une copie de la surface de l'icone a la taille du menu.
-	int w = 24, h = w;
-	cairo_surface_t *surface = cairo_image_surface_create (CAIRO_FORMAT_RGB24,
-		w,
-		h);
-	cairo_t *pCairoContext = cairo_create (surface);
-	cairo_scale (pCairoContext, (double)w/iWidth, (double)h/iHeight);
-	cairo_set_source_surface (pCairoContext, pIcon->pIconBuffer, 0., 0.);
-	cairo_paint (pCairoContext);
-	cairo_destroy (pCairoContext);
-	guchar *d, *data = cairo_image_surface_get_data (surface);
-	int r = cairo_image_surface_get_stride (surface);
-	
-	// on la convertit en un pixbuf.
-	GdkPixbuf *pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB,
-		TRUE,
-		8,
-		w,
-		h);
-	guchar *p, *pixels = gdk_pixbuf_get_pixels (pixbuf);
-	int iNbChannels = gdk_pixbuf_get_n_channels (pixbuf);
-	int iRowstride = gdk_pixbuf_get_rowstride (pixbuf);
-	
-	int x, y;
-	int red, green, blue;
-	float fAlphaFactor;
-	for (y = 0; y < h; y ++)
+	GdkPixbuf *pixbuf = NULL;
+	if (iWidth > 0 && iHeight > 0 && pIcon->pIconBuffer != NULL)
 	{
-		for (x = 0; x < w; x ++)
+		int w = 24, h = w;
+		cairo_surface_t *surface = cairo_image_surface_create (CAIRO_FORMAT_RGB24,
+			w,
+			h);
+		cairo_t *pCairoContext = cairo_create (surface);
+		cairo_scale (pCairoContext, (double)w/iWidth, (double)h/iHeight);
+		cairo_set_source_surface (pCairoContext, pIcon->pIconBuffer, 0., 0.);
+		cairo_paint (pCairoContext);
+		cairo_destroy (pCairoContext);
+		guchar *d, *data = cairo_image_surface_get_data (surface);
+		int r = cairo_image_surface_get_stride (surface);
+		
+		// on la convertit en un pixbuf.
+		pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB,
+			TRUE,
+			8,
+			w,
+			h);
+		guchar *p, *pixels = gdk_pixbuf_get_pixels (pixbuf);
+		int iNbChannels = gdk_pixbuf_get_n_channels (pixbuf);
+		int iRowstride = gdk_pixbuf_get_rowstride (pixbuf);
+		
+		int x, y;
+		int red, green, blue;
+		float fAlphaFactor;
+		for (y = 0; y < h; y ++)
 		{
-			p = pixels + y * iRowstride + x * iNbChannels;
-			d = data + y * r + x * 4;
-			
-			fAlphaFactor = (float) d[3] / 255;
-			if (fAlphaFactor != 0)
+			for (x = 0; x < w; x ++)
 			{
-				red = d[0] / fAlphaFactor;
-				green = d[1] / fAlphaFactor;
-				blue = d[2] / fAlphaFactor;
+				p = pixels + y * iRowstride + x * iNbChannels;
+				d = data + y * r + x * 4;
+				
+				fAlphaFactor = (float) d[3] / 255;
+				if (fAlphaFactor != 0)
+				{
+					red = d[0] / fAlphaFactor;
+					green = d[1] / fAlphaFactor;
+					blue = d[2] / fAlphaFactor;
+				}
+				else
+				{
+					red = blue = green = 0;
+				}
+				p[0] = blue;
+				p[1] = green;
+				p[2] = red;
+				p[3] = d[3];
 			}
-			else
-			{
-				red = blue = green = 0;
-			}
-			p[0] = blue;
-			p[1] = green;
-			p[2] = red;
-			p[3] = d[3];
 		}
+		
+		cairo_surface_destroy (surface);
 	}
 	
-	cairo_surface_destroy (surface);
-	
 	// on ajoute une entree au menu avec le pixbuf.
 	GtkWidget *pMenuItem = gtk_image_menu_item_new_with_label (pIcon->cName);
-	GtkWidget *image = gtk_image_new_from_pixbuf (pixbuf);
-	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (pMenuItem), image);
+	if (pixbuf)
+	{
+		GtkWidget *image = gtk_image_new_from_pixbuf (pixbuf);
+		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (pMenuItem), image);
+		g_object_unref (pixbuf);
+	}
 	gtk_menu_shell_append  (GTK_MENU_SHELL (pMenu), pMenuItem);
 	g_signal_connect (G_OBJECT (pMenuItem), "activate", G_CALLBACK (_show_window), pIcon);
-	
-	g_object_unref (pixbuf);
 }
 void cd_switcher_build_windows_list (GtkWidget *pMenu)
 {
@@ -595,7 +598,7 @@ void cd_switcher_build_windows_list (GtkWidget *pMenu)
 	
 	// chaque bureau/viewport.
 	int iNumDesktop=0, iNumViewportX=0, iNumViewportY=0;
-	int k = 0, N = g_iNbDesktops * g_iNbViewportX * g_iNbViewportY;
+	int k = 0, N = g_desktopGeometry.iNbDesktops * g_desktopGeometry.iNbViewportX * g_desktopGeometry.iNbViewportY;
 	int iIndex = cd_switcher_compute_index (myData.switcher.iCurrentDesktop, myData.switcher.iCurrentViewportX, myData.switcher.iCurrentViewportY);
 	GString *sDesktopName = g_string_new ("");
 	int i, j;
@@ -611,16 +614,16 @@ void cd_switcher_build_windows_list (GtkWidget *pMenu)
 			if (k < myConfig.iNbNames)
 			{
 				if (k == iIndex)
-					g_string_printf (sDesktopName, "<b>%s (%s)</b>", myConfig.cDesktopNames[k], D_("current"));
+					g_string_printf (sDesktopName, "<b>%s (%s)</b>", myConfig.cDesktopNames[k], D_("Current"));
 				else
 					g_string_printf (sDesktopName, "<b>%s</b>", myConfig.cDesktopNames[k]);
 			}
 			else
 			{
 				if (k == iIndex)
-					g_string_printf (sDesktopName, "<b>%s %d (%s)</b>", D_("desktop"), k+1, D_("current"));
+					g_string_printf (sDesktopName, "<b>%s %d (%s)</b>", D_("Desktop"), k+1, D_("Current"));
 				else
-					g_string_printf (sDesktopName, "<b>%s %d</b>", D_("desktop"), k+1);
+					g_string_printf (sDesktopName, "<b>%s %d</b>", D_("Desktop"), k+1);
 			}  // les noms des bureaux : _NET_DESKTOP_NAMES, UTF8_STRING
 			pMenuItem = gtk_menu_item_new ();
 			GtkWidget *pLabel = gtk_label_new (sDesktopName->str);
@@ -644,11 +647,11 @@ void cd_switcher_build_windows_list (GtkWidget *pMenu)
 			
 			// on passe au viewport suivant.
 			iNumViewportX ++;
-			if (iNumViewportX == g_iNbViewportX)
+			if (iNumViewportX == g_desktopGeometry.iNbViewportX)
 			{
 				iNumViewportX = 0;
 				iNumViewportY ++;
-				if (iNumViewportY == g_iNbViewportY)
+				if (iNumViewportY == g_desktopGeometry.iNbViewportY)
 				{
 					iNumViewportY = 0;
 					iNumDesktop ++;
@@ -672,8 +675,8 @@ static void _cd_switcher_move_window_to_viewport (Icon *pIcon, int iNumDesktop,
 	
 	cairo_dock_move_xwindow_to_nth_desktop (pIcon->Xid,
 		iDestNumDesktop,
-		(iDestNumViewportX - myData.switcher.iCurrentViewportX) * g_iXScreenWidth[CAIRO_DOCK_HORIZONTAL],
-		(iDestNumViewportY - myData.switcher.iCurrentViewportY) * g_iXScreenHeight[CAIRO_DOCK_HORIZONTAL]);
+		(iDestNumViewportX - myData.switcher.iCurrentViewportX) * g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL],
+		(iDestNumViewportY - myData.switcher.iCurrentViewportY) * g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL]);
 }
 void cd_switcher_move_current_desktop_to (int iNumDesktop, int iNumViewportX, int iNumViewportY)
 {
