@@ -29,17 +29,51 @@
 #include "applet-notifications.h"
 
 
-CD_APPLET_ON_MIDDLE_CLICK_BEGIN
-	if (myConfig.iActionOnMiddleClick == 0)
+static void _compiz_dbus_action (const gchar *cCommand)  // taken from the Compiz-Icon applet, thanks ChangFu !
+{
+	if (! cairo_dock_dbus_detect_application ("org.freedesktop.compiz"))
 	{
-		GtkWidget *pMenu = gtk_menu_new ();
-		cd_switcher_build_windows_list (pMenu);
-		cairo_dock_popup_menu_on_container (pMenu, myContainer);
+		cd_warning  ("Dbus plug-in must be activated in Compiz !");
+		cairo_dock_show_temporary_dialog_with_icon (D_("You need to run Compiz and activate its 'DBus' plug-in."), myIcon, myContainer, 6000, "same icon");
 	}
-	else
+	
+	GError *erreur = NULL;
+	gchar *cDbusCommand = g_strdup_printf ("dbus-send --type=method_call --dest=org.freedesktop.compiz /org/freedesktop/compiz/%s org.freedesktop.compiz.activate string:'root' int32:%d", cCommand, cairo_dock_get_root_id ());
+	g_spawn_command_line_async (cDbusCommand, &erreur);
+	if (erreur != NULL)
 	{
-		gboolean bDesktopIsVisible = cairo_dock_desktop_is_visible ();
-		cairo_dock_show_hide_desktop (! bDesktopIsVisible);
+		cd_warning ("ShowDesktop : when trying to send '%s' : %s", cDbusCommand, erreur->message);
+		g_error_free (erreur);
+	}
+	g_free (cDbusCommand);
+}
+static void _cd_expose (void)
+{
+	_compiz_dbus_action ("expo/allscreens/expo_button");  // expo avant la 0.7
+}
+
+CD_APPLET_ON_MIDDLE_CLICK_BEGIN
+	switch (myConfig.iActionOnMiddleClick)
+	{
+		case SWICTHER_WINDOWS_LIST:
+		default:
+		{
+			GtkWidget *pMenu = gtk_menu_new ();
+			cd_switcher_build_windows_list (pMenu);
+			CD_APPLET_POPUP_MENU_ON_MY_ICON (pMenu);
+		}
+		break;
+		case SWICTHER_SHOW_DESKTOP:
+		{
+			gboolean bDesktopIsVisible = cairo_dock_desktop_is_visible ();
+			cairo_dock_show_hide_desktop (! bDesktopIsVisible);
+		}
+		break;
+		case SWICTHER_EXPOSE:
+		{
+			_cd_expose ();
+		}
+		break;
 	}
 CD_APPLET_ON_MIDDLE_CLICK_END
 
@@ -69,17 +103,28 @@ static gboolean _cd_switcher_get_viewport_from_clic (Icon *pClickedIcon, int *iN
 			iMouseX = myContainer->iMouseX - myIcon->fDrawX;
 			iMouseY = myContainer->iMouseY - myIcon->fDrawY;
 		}
-		if (! myContainer->bIsHorizontal)
+		
+		double w, h;
+		if (myContainer->bIsHorizontal)
 		{
+			w = myIcon->fWidth * myIcon->fScale;
+			h = myIcon->fHeight * myIcon->fScale;
+		}
+		else
+		{
+			h = myIcon->fWidth * myIcon->fScale;
+			w = myIcon->fHeight * myIcon->fScale;
 			double tmp = iMouseX;
 			iMouseX = iMouseY;
 			iMouseY = tmp;
 		}
-		
-		double w = myIcon->fWidth * myIcon->fScale - 2 * myData.switcher.fOffsetX;
-		double h = myIcon->fHeight * myIcon->fScale - 2 * myData.switcher.fOffsetY;
-		iMouseX -= myData.switcher.fOffsetX;
-		iMouseY -= myData.switcher.fOffsetY;
+		double fMaxScale = cairo_dock_get_max_scale (myContainer);
+		double dx = myData.switcher.fOffsetX / fMaxScale * myIcon->fScale;
+		double dy = myData.switcher.fOffsetY / fMaxScale * myIcon->fScale;
+		w -= 2 * dx;
+		h -= 2 * dy;
+		iMouseX -= dx;
+		iMouseY -= dy;
 		
 		if (iMouseX < 0 || iMouseX > w || iMouseY < 0 || iMouseY > h)
 			return FALSE;
@@ -111,7 +156,7 @@ static gboolean _cd_switcher_get_viewport_from_clic (Icon *pClickedIcon, int *iN
 CD_APPLET_ON_CLICK_BEGIN
 	int iNumDesktop, iNumViewportX, iNumViewportY;
 	if (! _cd_switcher_get_viewport_from_clic (pClickedIcon, &iNumDesktop, &iNumViewportX, &iNumViewportY))
-		return CAIRO_DOCK_LET_PASS_NOTIFICATION;
+		CD_APPLET_LEAVE (CAIRO_DOCK_LET_PASS_NOTIFICATION);
 	
 	if (iNumDesktop != myData.switcher.iCurrentDesktop)
 		cairo_dock_set_current_desktop (iNumDesktop);
@@ -139,7 +184,7 @@ CD_APPLET_ON_SCROLL_BEGIN  // Merci ChangFu !
 		cd_switcher_compute_viewports_from_index (iIndex, &iNumDesktop, &iNumViewportX, &iNumViewportY);
 	}
 	else
-		return CAIRO_DOCK_LET_PASS_NOTIFICATION;
+		CD_APPLET_LEAVE (CAIRO_DOCK_LET_PASS_NOTIFICATION);
 	
 	cd_debug ("Switcher: switching to %d", iIndex);
 	if (iNumDesktop != myData.switcher.iCurrentDesktop)
@@ -212,21 +257,22 @@ static void _cd_switcher_show_desktop (GtkMenuItem *menu_item, CairoDockModuleIn
 	gboolean bDesktopIsVisible = cairo_dock_desktop_is_visible ();
 	cairo_dock_show_hide_desktop (! bDesktopIsVisible);
 }
+static void _cd_switcher_expose (GtkMenuItem *menu_item, CairoDockModuleInstance *myApplet)
+{
+	_cd_expose ();
+}
 CD_APPLET_ON_BUILD_MENU_BEGIN
+	// Sub-Menu
 	GtkWidget *pSubMenu = CD_APPLET_CREATE_MY_SUB_MENU ();
-	CD_APPLET_ADD_IN_MENU_WITH_STOCK (D_("Add a desktop"),
+	CD_APPLET_ADD_IN_MENU_WITH_STOCK (D_("Add a workspace"),
 		GTK_STOCK_ADD,
 		_cd_switcher_add_desktop,
 		pSubMenu);
-	CD_APPLET_ADD_IN_MENU_WITH_STOCK (D_("Remove last desktop"),
+	CD_APPLET_ADD_IN_MENU_WITH_STOCK (D_("Remove last workspace"),
 		GTK_STOCK_REMOVE,
 		_cd_switcher_remove_last_desktop,
 		pSubMenu);
-	CD_APPLET_ADD_IN_MENU_WITH_STOCK (D_("Refresh"),
-		GTK_STOCK_REFRESH,
-		_cd_switcher_refresh,
-		pSubMenu);
-
+	
 	int iNumDesktop, iNumViewportX, iNumViewportY;
 	if (_cd_switcher_get_viewport_from_clic (pClickedIcon, &iNumDesktop, &iNumViewportX, &iNumViewportY))
 	{
@@ -238,7 +284,7 @@ CD_APPLET_ON_BUILD_MENU_BEGIN
 			GINT_TO_POINTER (iIndex));
 		if (iNumDesktop != myData.switcher.iCurrentDesktop || iNumViewportX != myData.switcher.iCurrentViewportX || iNumViewportY != myData.switcher.iCurrentViewportY)
 		{
-			GtkWidget *pMenuItem = CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (D_("Move current desktop to this desktop"),
+			GtkWidget *pMenuItem = CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (D_("Move current workspace to this workspace"),
 				GTK_STOCK_JUMP_TO,
 				_cd_switcher_move_to_desktop,
 				pSubMenu,
@@ -247,19 +293,44 @@ CD_APPLET_ON_BUILD_MENU_BEGIN
 		}
 	}
 	
-	if (myConfig.iActionOnMiddleClick == 0)
+	// Main Menu
+	if (pSubMenu == CD_APPLET_MY_MENU)
+		CD_APPLET_ADD_SEPARATOR_IN_MENU (pSubMenu);
+	gchar *cLabel;
+	///if (myConfig.iActionOnMiddleClick != 0)
 	{
-		CD_APPLET_ADD_IN_MENU_WITH_STOCK (D_("Show the desktop"),
+		cLabel = (myConfig.iActionOnMiddleClick == SWICTHER_WINDOWS_LIST ? g_strdup_printf ("%s (%s)", D_("Windows List"), D_("middle-click")) : g_strdup (D_("Windows List")));
+		GtkWidget *pWindowsListMenu = CD_APPLET_ADD_SUB_MENU_WITH_IMAGE (cLabel, CD_APPLET_MY_MENU, GTK_STOCK_DND_MULTIPLE);
+		g_free (cLabel);
+		cd_switcher_build_windows_list (pWindowsListMenu);
+	}
+	///if (myConfig.iActionOnMiddleClick != 1)
+	{
+		cLabel = (myConfig.iActionOnMiddleClick == SWICTHER_SHOW_DESKTOP ? g_strdup_printf ("%s (%s)", D_("Show the desktop"), D_("middle-click")) : g_strdup (D_("Show the desktop")));
+		CD_APPLET_ADD_IN_MENU_WITH_STOCK (cLabel,
 			GTK_STOCK_FULLSCREEN,
 			_cd_switcher_show_desktop,
-			pSubMenu);
+			CD_APPLET_MY_MENU);
+		g_free (cLabel);
 	}
-	else
+	///if (myConfig.iActionOnMiddleClick != 2)
 	{
-		pSubMenu = CD_APPLET_ADD_SUB_MENU_WITH_IMAGE (D_("Windows List"), CD_APPLET_MY_MENU, GTK_STOCK_DND_MULTIPLE);
-		cd_switcher_build_windows_list (pSubMenu);
+		cLabel = (myConfig.iActionOnMiddleClick == SWICTHER_EXPOSE ? g_strdup_printf ("%s (%s)", D_("Expose all the desktops (Compiz)"), D_("middle-click")) : g_strdup (D_("Expose all the desktops (Compiz)")));
+		CD_APPLET_ADD_IN_MENU_WITH_STOCK (cLabel,
+			GTK_STOCK_LEAVE_FULLSCREEN,
+			_cd_switcher_expose,
+			CD_APPLET_MY_MENU);
+		g_free (cLabel);
 	}
 	
+	// Sub-Menu
+	CD_APPLET_ADD_SEPARATOR_IN_MENU (pSubMenu);
+	CD_APPLET_ADD_IN_MENU_WITH_STOCK (D_("Refresh"),
+		GTK_STOCK_REFRESH,
+		_cd_switcher_refresh,
+		pSubMenu);
+	
+	CD_APPLET_ADD_SEPARATOR_IN_MENU (pSubMenu);
 	CD_APPLET_ADD_ABOUT_IN_MENU (pSubMenu);
 CD_APPLET_ON_BUILD_MENU_END
 
@@ -273,7 +344,7 @@ static gboolean _cd_switcher_redraw_main_icon_idle (CairoDockModuleInstance *myA
 		cd_switcher_compute_nb_lines_and_columns ();
 		cd_switcher_get_current_desktop ();
 	}
- 	cd_switcher_draw_main_icon ();
+	cd_switcher_draw_main_icon ();
 	myData.iSidRedrawMainIconIdle = 0;
 	CD_APPLET_LEAVE (FALSE);
 	//return FALSE;
@@ -290,9 +361,7 @@ gboolean on_change_active_window (CairoDockModuleInstance *myApplet, Window *XAc
 {
 	CD_APPLET_ENTER;
 	_cd_switcher_queue_draw (myApplet);
-	//cd_switcher_draw_main_icon ();
 	CD_APPLET_LEAVE (CAIRO_DOCK_LET_PASS_NOTIFICATION);
-	//return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 }
 
 gboolean on_change_desktop (CairoDockModuleInstance *myApplet)
@@ -332,9 +401,9 @@ gboolean on_change_desktop (CairoDockModuleInstance *myApplet)
 			if (icon->fOrder == iPreviousIndex)  // l'ancienne icone du bureau courant.
 			{
 				if (iPreviousIndex < myConfig.iNbNames)
-					cairo_dock_set_icon_name (myDrawContext, myConfig.cDesktopNames[iPreviousIndex], icon, pContainer);
+					cairo_dock_set_icon_name (myConfig.cDesktopNames[iPreviousIndex], icon, pContainer);
 				else
-					cairo_dock_set_icon_name_full (myDrawContext, icon, pContainer, "%s %d", D_("Desktop"), iPreviousIndex+1);
+					cairo_dock_set_icon_name_printf (icon, pContainer, "%s %d", D_("Desktop"), iPreviousIndex+1);
 				icon->bHasIndicator = FALSE;
 				icon->fAlpha = 1.;
 				if (myDock)
@@ -342,7 +411,7 @@ gboolean on_change_desktop (CairoDockModuleInstance *myApplet)
 			}
 			if (icon->fOrder == iIndex)  // c'est l'icone du bureau courant.
 			{
-				cairo_dock_set_icon_name_full (myDrawContext, icon, pContainer, "%s (%d)", D_("Current"), iIndex+1);
+				cairo_dock_set_icon_name_printf (icon, pContainer, "%s (%d)", D_("Current"), iIndex+1);
 				icon->bHasIndicator = TRUE;
 				icon->fAlpha = .7;
 				if (myDock)
@@ -354,7 +423,6 @@ gboolean on_change_desktop (CairoDockModuleInstance *myApplet)
 	}
 	
 	CD_APPLET_LEAVE (CAIRO_DOCK_LET_PASS_NOTIFICATION);
-	//return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 }
 
 gboolean on_change_screen_geometry (CairoDockModuleInstance *myApplet)
@@ -363,16 +431,14 @@ gboolean on_change_screen_geometry (CairoDockModuleInstance *myApplet)
 	cd_debug ("");
 	cd_switcher_update_from_screen_geometry ();
 	CD_APPLET_LEAVE (CAIRO_DOCK_LET_PASS_NOTIFICATION);
-	//return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 }
 
-gboolean on_window_configured (CairoDockModuleInstance *myApplet, XConfigureEvent *xconfigure)
+gboolean on_window_configured (CairoDockModuleInstance *myApplet, Window Xid, XConfigureEvent *xconfigure)
 {
 	CD_APPLET_ENTER;
 	cd_debug ("");
 	_cd_switcher_queue_draw (myApplet);
 	CD_APPLET_LEAVE (CAIRO_DOCK_LET_PASS_NOTIFICATION);
-	//return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 }
 
 
@@ -381,12 +447,10 @@ gboolean on_mouse_moved (CairoDockModuleInstance *myApplet, CairoContainer *pCon
 	CD_APPLET_ENTER;
 	if (! myIcon->bPointed || ! pContainer->bInside)
 		CD_APPLET_LEAVE (CAIRO_DOCK_LET_PASS_NOTIFICATION);
-		//return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 	
 	int iNumDesktop, iNumViewportX, iNumViewportY;
 	if (! _cd_switcher_get_viewport_from_clic (myIcon, &iNumDesktop, &iNumViewportX, &iNumViewportY))
 		CD_APPLET_LEAVE (CAIRO_DOCK_LET_PASS_NOTIFICATION);
-		//return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 	
 	int iIndex = cd_switcher_compute_index (iNumDesktop, iNumViewportX, iNumViewportY);
 	if (iIndex != myData.iPrevIndexHovered)
@@ -407,7 +471,6 @@ gboolean on_mouse_moved (CairoDockModuleInstance *myApplet, CairoContainer *pCon
 			*bStartAnimation = TRUE;
 	}
 	CD_APPLET_LEAVE (CAIRO_DOCK_LET_PASS_NOTIFICATION);
-	//return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 }
 
 gboolean on_update_desklet (CairoDockModuleInstance *myApplet, CairoContainer *pContainer, gboolean *bContinueAnimation)
@@ -431,7 +494,6 @@ gboolean on_update_desklet (CairoDockModuleInstance *myApplet, CairoContainer *p
 	}
 	CAIRO_DOCK_REDRAW_MY_CONTAINER;
 	CD_APPLET_LEAVE (CAIRO_DOCK_LET_PASS_NOTIFICATION);
-	//return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 }
 
 gboolean on_render_desklet (CairoDockModuleInstance *myApplet, CairoContainer *pContainer, cairo_t *pCairoContext)
@@ -448,7 +510,6 @@ gboolean on_render_desklet (CairoDockModuleInstance *myApplet, CairoContainer *p
 	{
 		if (myIcon->pTextBuffer == NULL)
 			CD_APPLET_LEAVE (CAIRO_DOCK_LET_PASS_NOTIFICATION);
-			//return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 		cairo_save (pCairoContext);
 		cairo_translate (pCairoContext, x, y);
 		cairo_set_source_surface (pCairoContext, myIcon->pTextBuffer, - myIcon->iTextWidth/2, - myIcon->iTextHeight/2);
@@ -459,18 +520,16 @@ gboolean on_render_desklet (CairoDockModuleInstance *myApplet, CairoContainer *p
 	{
 		if (myIcon->iLabelTexture == 0)
 			CD_APPLET_LEAVE (CAIRO_DOCK_LET_PASS_NOTIFICATION);
-			//return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 		glPushMatrix ();
 		if (myDesklet)
 			glTranslatef (-myDesklet->container.iWidth/2, -myDesklet->container.iHeight/2, -myDesklet->container.iHeight*(sqrt(3)/2));
-			glTranslatef (x - ((myIcon->iTextWidth & 1) ? 0.5 : 0.),
-				y - ((myIcon->iTextHeight & 1) ? 0.5 : 0.),
-				0);
+		glTranslatef (x - ((myIcon->iTextWidth & 1) ? 0.5 : 0.),
+			y - ((myIcon->iTextHeight & 1) ? 0.5 : 0.),
+			0);
 		cairo_dock_draw_texture_with_alpha (myIcon->iLabelTexture, myIcon->iTextWidth, myIcon->iTextHeight, myData.fDesktopNameAlpha);
 		glPopMatrix ();
 	}
 	CD_APPLET_LEAVE (CAIRO_DOCK_LET_PASS_NOTIFICATION);
-	//return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 }
 
 gboolean on_leave_desklet (CairoDockModuleInstance *myApplet, CairoContainer *pContainer, gboolean *bStartAnimation)
