@@ -71,7 +71,7 @@ void term_on_keybinding_pull(const char *keystring, gpointer user_data)
 				}
 				bHasFocus |= (GDK_WINDOW_XID (myDesklet->container.pWidget->window) == cairo_dock_get_current_active_window ());
 			}
-			g_print ("%s (%d)\n", __func__, bHasFocus);
+			cd_debug ("%s (%d)\n", __func__, bHasFocus);
 			
 			if (bHasFocus)
 			{
@@ -107,15 +107,20 @@ static gchar *_get_label_and_color (const gchar *cLabel, GdkColor *pColor, gbool
 {
 	gchar *cUsefulLabel;
 	gchar *str = strchr (cLabel, '>');
+	//g_print ("%s (%s)\n", __func__, cLabel);
 	if (cLabel != NULL && strncmp (cLabel, "<span color='", 13) == 0 && str != NULL)  // approximatif mais devrait suffire.
 	{
-		gchar *cColor = g_strndup (cLabel+13, 7);
-		if (pColor != NULL)
+		const gchar *col = cLabel+13;
+		gchar *col_end = strchr (col+1, '\'');
+		if (col_end)
+		{
+			gchar *cColor = g_strndup (col, col_end - col);
+			//g_print ("cColor : %s\n", cColor);
 			*bColorSet = gdk_color_parse (cColor, pColor);
-		g_free (cColor);
-		
+			g_free (cColor);
+		}
 		cUsefulLabel = g_strdup (str+1);
-		str = strrchr (cLabel, '<');
+		str = strrchr (cUsefulLabel, '<');
 		if (str != NULL && strcmp (str, "</span>") == 0)
 			*str = '\0';
 	}
@@ -141,7 +146,7 @@ void terminal_rename_tab (GtkWidget *vterm)
 	if (pTabWidgetList != NULL && pTabWidgetList->data != NULL)
 	{
 		GtkLabel *pLabel = pTabWidgetList->data;
-		const gchar *cCurrentName = gtk_label_get_text (pLabel);
+		const gchar *cCurrentName = gtk_label_get_label (pLabel);
 		GdkColor color;
 		gboolean bColorSet = FALSE;
 		gchar *cUsefulLabel = _get_label_and_color (cCurrentName, &color, &bColorSet);
@@ -165,6 +170,7 @@ void terminal_rename_tab (GtkWidget *vterm)
 			}
 			g_free (cNewName);
 		}
+		g_list_free (pTabWidgetList);
 	}
 }
 
@@ -175,13 +181,13 @@ static void _set_color (GtkColorSelection *pColorSelection, GtkLabel *pLabel)
 	
 	gchar *cColor = gdk_color_to_string (&color);
 	
-	const gchar *cCurrentLabel = gtk_label_get_text (pLabel);
-	gchar *cUsefulLabel = _get_label_and_color (cCurrentLabel, NULL, NULL);
-	gchar *cNewLabel = g_strdup_printf ("<span color='%s'>%s</span>", cColor, cUsefulLabel);
+	const gchar *cCurrentLabel = gtk_label_get_text (pLabel);  // recupere le texte sans les balises pango.
+	//gchar *cUsefulLabel = _get_label_and_color (cCurrentLabel, NULL, NULL);
+	gchar *cNewLabel = g_strdup_printf ("<span color='%s'>%s</span>", cColor, cCurrentLabel);
 	gtk_label_set_markup (pLabel, cNewLabel);
 	
 	g_free (cNewLabel);
-	g_free (cUsefulLabel);
+	//g_free (cUsefulLabel);
 	g_free (cColor);
 }
 void terminal_change_color_tab (GtkWidget *vterm)
@@ -283,25 +289,51 @@ void term_apply_settings (void)
 	}
 }
 
-static void on_terminal_child_exited(VteTerminal *vteterminal,
+static void on_terminal_child_exited(VteTerminal *vterm,
                                      gpointer t)
 {
-	gint p = gtk_notebook_page_num(GTK_NOTEBOOK(myData.tab), GTK_WIDGET(vteterminal));
+	gint p = gtk_notebook_page_num(GTK_NOTEBOOK(myData.tab), GTK_WIDGET(vterm));
 	gint sz = gtk_notebook_get_n_pages(GTK_NOTEBOOK(myData.tab));
 
 	if (sz > 1)
 		gtk_notebook_remove_page(GTK_NOTEBOOK(myData.tab), p);
 	else {
 		// \r needed to return to the beginning of the line
-		vte_terminal_feed(VTE_TERMINAL(vteterminal), "Shell exited. Another one is launching...\r\n\n", -1);
-		vte_terminal_fork_command(VTE_TERMINAL(vteterminal),
-			NULL,
-			NULL,
-			NULL,
-			"~/",
-			FALSE,
-			FALSE,
-			FALSE);
+		vte_terminal_feed(VTE_TERMINAL(vterm), "Shell exited. Another one is launching...\r\n\n", -1);
+		
+		pid_t pid; 
+		#if (GLIB_MAJOR_VERSION > 2) || (GLIB_MAJOR_VERSION == 2 && GLIB_MINOR_VERSION >= 18)  // VTE_CHECK_VERSION doesn't exist in Hardy.
+			#if VTE_CHECK_VERSION(0,26,0)
+			vte_terminal_fork_command_full (VTE_TERMINAL(vterm),
+				VTE_PTY_NO_LASTLOG | VTE_PTY_NO_UTMP | VTE_PTY_NO_WTMP,
+				"~/",
+				NULL,  // argv
+				NULL,  // envv
+				0,  // GSpawnFlags spawn_flags
+				NULL,  // GSpawnChildSetupFunc child_setup
+				NULL,  // gpointer child_setup_data
+				&pid,
+				NULL);
+			#else
+			pid = vte_terminal_fork_command (VTE_TERMINAL(vterm),
+				NULL,
+				NULL,
+				NULL,
+				"~/",
+				FALSE,
+				FALSE,
+				FALSE);
+			#endif
+		#else
+			pid = vte_terminal_fork_command (VTE_TERMINAL(vterm),
+				NULL,
+				NULL,
+				NULL,
+				"~/",
+				FALSE,
+				FALSE,
+				FALSE);
+		#endif
 		if (myData.dialog)
 			cairo_dock_hide_dialog (myData.dialog);
 		else if (myDesklet && myConfig.shortcut)
@@ -394,7 +426,7 @@ static GtkWidget *_terminal_build_menu_tab (GtkWidget *vterm)
 
 static gboolean applet_on_terminal_press_cb(GtkWidget *vterm, GdkEventButton *event, gpointer user_data)
 {
-	g_print ("%s ()\n", __func__);
+	cd_debug ("%s ()\n", __func__);
 	if (event->button == 3)
 	{
 		GtkWidget *menu = _terminal_build_menu_tab (vterm);
@@ -411,7 +443,7 @@ static gboolean applet_on_terminal_press_cb(GtkWidget *vterm, GdkEventButton *ev
 	}
 	return FALSE;
 }
-static void applet_on_terminal_eof(VteTerminal *vteterminal,
+static void applet_on_terminal_eof(VteTerminal *vterm,
                                    gpointer     user_data)
 {
 	cd_debug ("youkata EOF");
@@ -503,14 +535,39 @@ void terminal_new_tab(void)
 	vte_terminal_set_opacity(VTE_TERMINAL(vterm), myConfig.transparency);
 	#endif
 	vte_terminal_set_emulation(VTE_TERMINAL(vterm), "xterm");
-	vte_terminal_fork_command(VTE_TERMINAL(vterm),
-		NULL,
-		NULL,
-		NULL,
-		"~/",
-		FALSE,
-		FALSE,
-		FALSE);
+	pid_t pid; 
+	#if (GLIB_MAJOR_VERSION > 2) || (GLIB_MAJOR_VERSION == 2 && GLIB_MINOR_VERSION >= 18)  // VTE_CHECK_VERSION doesn't exist in Hardy.
+		#if VTE_CHECK_VERSION(0,26,0)
+		vte_terminal_fork_command_full (VTE_TERMINAL(vterm),
+			VTE_PTY_NO_LASTLOG | VTE_PTY_NO_UTMP | VTE_PTY_NO_WTMP,
+			"~/",
+			NULL,  // argv
+			NULL,  // envv
+			0,  // GSpawnFlags spawn_flags
+			NULL,  // GSpawnChildSetupFunc child_setup
+			NULL,  // gpointer child_setup_data
+			&pid,
+			NULL);
+		#else
+		pid = vte_terminal_fork_command (VTE_TERMINAL(vterm),
+			NULL,
+			NULL,
+			NULL,
+			"~/",
+			FALSE,
+			FALSE,
+			FALSE);
+		#endif
+	#else
+		pid = vte_terminal_fork_command (VTE_TERMINAL(vterm),
+			NULL,
+			NULL,
+			NULL,
+			"~/",
+			FALSE,
+			FALSE,
+			FALSE);
+	#endif
 	g_signal_connect (G_OBJECT (vterm), "child-exited",
 				G_CALLBACK (on_terminal_child_exited), NULL);
 	g_signal_connect (G_OBJECT (vterm), "button-release-event",
@@ -657,7 +714,7 @@ static gboolean on_button_press_tab (GtkWidget* pWidget,
 	GdkEventButton* pButton,
 	gpointer data)
 {
-	g_print ("%s (%d;%d)\n", __func__, (int)pButton->x, (int)pButton->y);
+	cd_debug ("%s (%d;%d)\n", __func__, (int)pButton->x, (int)pButton->y);
 	GtkWidget *vterm = _terminal_find_clicked_tab_child (pButton->x, pButton->y);
 	if (pButton->type == GDK_2BUTTON_PRESS)
 	{
@@ -741,6 +798,6 @@ void terminal_build_and_show_tab (void)
 	else
 	{
 		cairo_dock_add_interactive_widget_to_desklet (myData.tab, myDesklet);
-		cairo_dock_set_desklet_renderer_by_name (myDesklet, NULL, NULL, ! CAIRO_DOCK_LOAD_ICONS_FOR_DESKLET, NULL);
+		CD_APPLET_SET_DESKLET_RENDERER (NULL);  // pour empecher le clignotement du au double-buffer.
 	}
 }
